@@ -55,5 +55,5 @@ stc.save(f"mne_{method}_raw_inverse_{label_name}", overwrite=True)
 # View activation time-series
 plt.plot(1e3 * stc.times, stc.data[::100, :].T)
 plt.xlabel("time (ms)")
-plt.ylabel("%s value" % method)
+plt.ylabel(f"{method} value")
 plt.show()
