@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _ex-source-leakage:
 
@@ -18,21 +17,22 @@ which is ordered based on the locations of the regions in the axial plane.
 #          Nicolas P. Rougier (graph code borrowed from his matplotlib gallery)
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
+from mne_connectivity.viz import plot_connectivity_circle
 
 import mne
 from mne.datasets import sample
-from mne.minimum_norm import (read_inverse_operator,
-                              make_inverse_resolution_matrix,
-                              get_point_spread)
-
+from mne.minimum_norm import (
+    get_point_spread,
+    make_inverse_resolution_matrix,
+    read_inverse_operator,
+)
 from mne.viz import circular_layout
-from mne_connectivity.viz import plot_connectivity_circle
-
 
 print(__doc__)
 
@@ -44,20 +44,20 @@ print(__doc__)
 # resolution matrices for different methods.
 
 data_path = sample.data_path()
-subjects_dir = data_path / 'subjects'
-meg_path = data_path / 'MEG' / 'sample'
-fname_fwd = meg_path / 'sample_audvis-meg-eeg-oct-6-fwd.fif'
-fname_inv = meg_path / 'sample_audvis-meg-oct-6-meg-fixed-inv.fif'
+subjects_dir = data_path / "subjects"
+meg_path = data_path / "MEG" / "sample"
+fname_fwd = meg_path / "sample_audvis-meg-eeg-oct-6-fwd.fif"
+fname_inv = meg_path / "sample_audvis-meg-oct-6-meg-fixed-inv.fif"
 forward = mne.read_forward_solution(fname_fwd)
 # Convert forward solution to fixed source orientations
-mne.convert_forward_solution(
-    forward, surf_ori=True, force_fixed=True, copy=False)
+mne.convert_forward_solution(forward, surf_ori=True, force_fixed=True, copy=False)
 inverse_operator = read_inverse_operator(fname_inv)
 
 # Compute resolution matrices for MNE
-rm_mne = make_inverse_resolution_matrix(forward, inverse_operator,
-                                        method='MNE', lambda2=1. / 3.**2)
-src = inverse_operator['src']
+rm_mne = make_inverse_resolution_matrix(
+    forward, inverse_operator, method="MNE", lambda2=1.0 / 3.0**2
+)
+src = inverse_operator["src"]
 del forward, inverse_operator  # save memory
 
 # %%
@@ -65,13 +65,12 @@ del forward, inverse_operator  # save memory
 # --------------------------------------------------
 #
 # Get labels for FreeSurfer 'aparc' cortical parcellation with 34 labels/hemi
-labels = mne.read_labels_from_annot('sample', parc='aparc',
-                                    subjects_dir=subjects_dir)
+labels = mne.read_labels_from_annot("sample", parc="aparc", subjects_dir=subjects_dir)
 n_labels = len(labels)
 label_colors = [label.color for label in labels]
 # First, we reorder the labels based on their location in the left hemi
 label_names = [label.name for label in labels]
-lh_labels = [name for name in label_names if name.endswith('lh')]
+lh_labels = [name for name in label_names if name.endswith("lh")]
 
 # Get the y-location of the label
 label_ypos = list()
@@ -84,7 +83,7 @@ for name in lh_labels:
 lh_labels = [label for (yp, label) in sorted(zip(label_ypos, lh_labels))]
 
 # For the right hemi
-rh_labels = [label[:-2] + 'rh' for label in lh_labels]
+rh_labels = [label[:-2] + "rh" for label in lh_labels]
 
 # %%
 # Compute point-spread function summaries (PCA) for all labels
@@ -98,8 +97,8 @@ rh_labels = [label[:-2] + 'rh' for label in lh_labels]
 # spatial extents of labels.
 n_comp = 5
 stcs_psf_mne, pca_vars_mne = get_point_spread(
-    rm_mne, src, labels, mode='pca', n_comp=n_comp, norm=None,
-    return_pca_vars=True)
+    rm_mne, src, labels, mode="pca", n_comp=n_comp, norm=None, return_pca_vars=True
+)
 n_verts = rm_mne.shape[0]
 del rm_mne
 
@@ -110,7 +109,7 @@ del rm_mne
 
 with np.printoptions(precision=1):
     for [name, var] in zip(label_names, pca_vars_mne):
-        print(f'{name}: {var.sum():.1f}% {var}')
+        print(f"{name}: {var.sum():.1f}% {var}")
 
 # %%
 # The output shows the summed variance explained by the first five principal
@@ -133,15 +132,23 @@ leakage_mne = np.abs(np.corrcoef(psfs_mat))
 
 # Save the plot order and create a circular layout
 node_order = lh_labels[::-1] + rh_labels  # mirror label order across hemis
-node_angles = circular_layout(label_names, node_order, start_pos=90,
-                              group_boundaries=[0, len(label_names) / 2])
+node_angles = circular_layout(
+    label_names, node_order, start_pos=90, group_boundaries=[0, len(label_names) / 2]
+)
 # Plot the graph using node colors from the FreeSurfer parcellation. We only
 # show the 200 strongest connections.
 fig, ax = plt.subplots(
-    figsize=(8, 8), facecolor='black', subplot_kw=dict(projection='polar'))
-plot_connectivity_circle(leakage_mne, label_names, n_lines=200,
-                         node_angles=node_angles, node_colors=label_colors,
-                         title='MNE Leakage', ax=ax)
+    figsize=(8, 8), facecolor="black", subplot_kw=dict(projection="polar")
+)
+plot_connectivity_circle(
+    leakage_mne,
+    label_names,
+    n_lines=200,
+    node_angles=node_angles,
+    node_colors=label_colors,
+    title="MNE Leakage",
+    ax=ax,
+)
 
 # %%
 # Most leakage occurs for neighbouring regions, but also for deeper regions
@@ -176,20 +183,26 @@ max_val = np.max([stc_lh.data, stc_rh.data])
 # %%
 # Point-spread function for the lateral occipital label in the left hemisphere
 
-brain_lh = stc_lh.plot(subjects_dir=subjects_dir, subject='sample',
-                       hemi='both', views='caudal',
-                       clim=dict(kind='value',
-                                 pos_lims=(0, max_val / 2., max_val)))
-brain_lh.add_text(0.1, 0.9, label_names[idx[0]], 'title', font_size=16)
+brain_lh = stc_lh.plot(
+    subjects_dir=subjects_dir,
+    subject="sample",
+    hemi="both",
+    views="caudal",
+    clim=dict(kind="value", pos_lims=(0, max_val / 2.0, max_val)),
+)
+brain_lh.add_text(0.1, 0.9, label_names[idx[0]], "title", font_size=16)
 
 # %%
 # and in the right hemisphere.
 
-brain_rh = stc_rh.plot(subjects_dir=subjects_dir, subject='sample',
-                       hemi='both', views='caudal',
-                       clim=dict(kind='value',
-                                 pos_lims=(0, max_val / 2., max_val)))
-brain_rh.add_text(0.1, 0.9, label_names[idx[1]], 'title', font_size=16)
+brain_rh = stc_rh.plot(
+    subjects_dir=subjects_dir,
+    subject="sample",
+    hemi="both",
+    views="caudal",
+    clim=dict(kind="value", pos_lims=(0, max_val / 2.0, max_val)),
+)
+brain_rh.add_text(0.1, 0.9, label_names[idx[1]], "title", font_size=16)
 
 # %%
 # Both summary PSFs are confined to their respective hemispheres, indicating
