@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _ex-snr-estimate:
 
@@ -12,19 +11,20 @@ using a minimum-norm inverse operator.
 # Author: Eric Larson <larson.eric.d@gmail.com>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 
+from mne import read_evokeds
 from mne.datasets.sample import data_path
 from mne.minimum_norm import read_inverse_operator
-from mne import read_evokeds
 from mne.viz import plot_snr_estimate
 
 print(__doc__)
 
-data_dir = data_path() / 'MEG' / 'sample'
-fname_inv = data_dir / 'sample_audvis-meg-oct-6-meg-inv.fif'
-fname_evoked = data_dir / 'sample_audvis-ave.fif'
+data_dir = data_path() / "MEG" / "sample"
+fname_inv = data_dir / "sample_audvis-meg-oct-6-meg-inv.fif"
+fname_evoked = data_dir / "sample_audvis-ave.fif"
 
 inv = read_inverse_operator(fname_inv)
 evoked = read_evokeds(fname_evoked, baseline=(None, 0))[0]
