@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _ex-fnirs-artifacts:
 
@@ -13,14 +12,17 @@ how artifact correction techniques attempt to correct the data.
 # Authors: Robert Luke <mail@robertluke.net>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 
 import os
-import mne
 
-from mne.preprocessing.nirs import (optical_density,
-                                    temporal_derivative_distribution_repair)
+import mne
+from mne.preprocessing.nirs import (
+    optical_density,
+    temporal_derivative_distribution_repair,
+)
 
 # %%
 # Import data
@@ -32,12 +34,13 @@ from mne.preprocessing.nirs import (optical_density,
 # and plot these signals.
 
 fnirs_data_folder = mne.datasets.fnirs_motor.data_path()
-fnirs_cw_amplitude_dir = os.path.join(fnirs_data_folder, 'Participant-1')
+fnirs_cw_amplitude_dir = os.path.join(fnirs_data_folder, "Participant-1")
 raw_intensity = mne.io.read_raw_nirx(fnirs_cw_amplitude_dir, verbose=True)
 raw_intensity.load_data().resample(3, npad="auto")
 raw_od = optical_density(raw_intensity)
-new_annotations = mne.Annotations([31, 187, 317], [8, 8, 8],
-                                  ["Movement", "Movement", "Movement"])
+new_annotations = mne.Annotations(
+    [31, 187, 317], [8, 8, 8], ["Movement", "Movement", "Movement"]
+)
 raw_od.set_annotations(new_annotations)
 raw_od.plot(n_channels=15, duration=400, show_scrollbars=False)
 
@@ -62,10 +65,10 @@ raw_od.plot(n_channels=15, duration=400, show_scrollbars=False)
 corrupted_data = raw_od.get_data()
 corrupted_data[:, 298:302] = corrupted_data[:, 298:302] - 0.06
 corrupted_data[:, 450:750] = corrupted_data[:, 450:750] + 0.03
-corrupted_od = mne.io.RawArray(corrupted_data, raw_od.info,
-                               first_samp=raw_od.first_samp)
-new_annotations.append([95, 145, 245], [10, 10, 10],
-                       ["Spike", "Baseline", "Baseline"])
+corrupted_od = mne.io.RawArray(
+    corrupted_data, raw_od.info, first_samp=raw_od.first_samp
+)
+new_annotations.append([95, 145, 245], [10, 10, 10], ["Spike", "Baseline", "Baseline"])
 corrupted_od.set_annotations(new_annotations)
 
 corrupted_od.plot(n_channels=15, duration=400, show_scrollbars=False)
