@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _ex-interpolate-bad-channels:
 
@@ -18,6 +17,7 @@ Only the data in those channels is replaced.
 #          Mainak Jas <mainak.jas@telecom-paristech.fr>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 
@@ -29,24 +29,24 @@ from mne.datasets import sample
 print(__doc__)
 
 data_path = sample.data_path()
-meg_path = data_path / 'MEG' / 'sample'
-fname = meg_path / 'sample_audvis-ave.fif'
-evoked = mne.read_evokeds(fname, condition='Left Auditory',
-                          baseline=(None, 0))
+meg_path = data_path / "MEG" / "sample"
+fname = meg_path / "sample_audvis-ave.fif"
+evoked = mne.read_evokeds(fname, condition="Left Auditory", baseline=(None, 0))
 
 # plot with bads
-evoked.plot(exclude=[], picks=('grad', 'eeg'))
+evoked.plot(exclude=[], picks=("grad", "eeg"))
 
 # %%
 # Compute interpolation (also works with Raw and Epochs objects)
 evoked_interp = evoked.copy().interpolate_bads(reset_bads=False)
-evoked_interp.plot(exclude=[], picks=('grad', 'eeg'))
+evoked_interp.plot(exclude=[], picks=("grad", "eeg"))
 
 # %%
 # You can also use minimum-norm for EEG as well as MEG
 evoked_interp_mne = evoked.copy().interpolate_bads(
-    reset_bads=False, method=dict(eeg='MNE'), verbose=True)
-evoked_interp_mne.plot(exclude=[], picks=('grad', 'eeg'))
+    reset_bads=False, method=dict(eeg="MNE"), verbose=True
+)
+evoked_interp_mne.plot(exclude=[], picks=("grad", "eeg"))
 
 # %%
 # References
