@@ -361,6 +361,160 @@ def test_set_eeg_reference_rest():
     assert 0.995 < exp_var <= 1
 
 
+@testing.requires_testing_data
+@pytest.mark.parametrize("inst_type", ["raw", "epochs"])
+@pytest.mark.parametrize(
+    "ref_channels, expectation",
+    [
+        (
+            {2: "EEG 001"},
+            pytest.raises(
+                TypeError,
+                match="Keys in the ref_channels dict must be strings. "
+                "Your dict has keys of type int.",
+            ),
+        ),
+        (
+            {"EEG 001": (1, 2)},
+            pytest.raises(
+                TypeError,
+                match="Values in the ref_channels dict must be strings. "
+                "Your dict has values of type int.",
+            ),
+        ),
+        (
+            {"EEG 001": [1, 2]},
+            pytest.raises(
+                TypeError,
+                match="Values in the ref_channels dict must be strings. "
+                "Your dict has values of type int.",
+            ),
+        ),
+        (
+            {"EEG 999": "EEG 001"},
+            pytest.raises(
+                ValueError,
+                match=r"ref_channels dict contains invalid key\(s\) \(EEG 999\) "
+                "that are not names of channels in the instance.",
+            ),
+        ),
+        (
+            {"EEG 001": "EEG 999"},
+            pytest.raises(
+                ValueError,
+                match=r"ref_channels dict contains invalid value\(s\) \(EEG 999\) "
+                "that are not names of channels in the instance.",
+            ),
+        ),
+        (
+            {"EEG 001": "EEG 057"},
+            pytest.warns(
+                RuntimeWarning,
+                match=r"ref_channels dict contains value\(s\) \(EEG 057\) "
+                "that are marked as bad channels.",
+            ),
+        ),
+        (
+            {"EEG 001": "STI 001"},
+            pytest.warns(
+                RuntimeWarning,
+                match=(
+                    r"Channel EEG 001 \(eeg\) is referenced to channel "
+                    r"STI 001 which is a different channel type \(stim\)."
+                ),
+            ),
+        ),
+        (
+            {"EEG 001": "EEG 001"},
+            pytest.warns(
+                RuntimeWarning,
+                match=(
+                    "Channel EEG 001 is self-referenced, "
+                    "which will nullify the channel."
+                ),
+            ),
+        ),
+        (
+            {"EEG 001": "EEG 002", "EEG 002": "EEG 003", "EEG 003": "EEG 005"},
+            nullcontext(),
+        ),
+        (
+            {
+                "EEG 001": ["EEG 002", "EEG 003"],
+                "EEG 002": "EEG 003",
+                "EEG 003": "EEG 005",
+            },
+            nullcontext(),
+        ),
+    ],
+)
+def test_set_eeg_reference_dict(ref_channels, inst_type, expectation):
+    """Test setting dict-based reference."""
+    if inst_type == "raw":
+        inst = read_raw_fif(fif_fname).crop(0, 1).pick(picks=["eeg", "stim"])
+    # Test re-referencing Epochs object
+    elif inst_type == "epochs":
+        raw = read_raw_fif(fif_fname, preload=False)
+        events = read_events(eve_fname)
+        inst = Epochs(
+            raw,
+            events=events,
+            event_id=1,
+            tmin=-0.2,
+            tmax=0.5,
+            preload=False,
+        )
+    with pytest.raises(
+        RuntimeError,
+        match="By default, MNE does not load data.*Applying a reference requires.*",
+    ):
+        inst.set_eeg_reference(ref_channels=ref_channels)
+    inst.load_data()
+    inst.info["bads"] = ["EEG 057"]
+    with expectation:
+        reref, _ = set_eeg_reference(inst.copy(), ref_channels, copy=False)
+
+    if isinstance(expectation, nullcontext):
+        # Check that the custom_ref_applied is set correctly:
+        assert reref.info["custom_ref_applied"] == FIFF.FIFFV_MNE_CUSTOM_REF_ON
+
+        # Get raw data
+        _data = inst._data
+
+        # Get that channels that were and weren't re-referenced:
+        ch_raw = pick_channels(
+            inst.ch_names,
+            [ch for ch in inst.ch_names if ch not in list(ref_channels.keys())],
+        )
+        ch_reref = pick_channels(inst.ch_names, list(ref_channels.keys()), ordered=True)
+
+        # Check that the non re-reference channels are untouched:
+        assert_allclose(
+            _data[..., ch_raw, :], reref._data[..., ch_raw, :], 1e-6, atol=1e-15
+        )
+
+        # Compute the reference data:
+        ref_data = []
+        for val in ref_channels.values():
+            if isinstance(val, str):
+                val = [val]  # pick_channels expects a list
+            ref_data.append(
+                _data[..., pick_channels(inst.ch_names, val, ordered=True), :].mean(
+                    -2, keepdims=True
+                )
+            )
+        if inst_type == "epochs":
+            ref_data = np.concatenate(ref_data, axis=1)
+        else:
+            ref_data = np.squeeze(np.array(ref_data))
+        assert_allclose(
+            _data[..., ch_reref, :],
+            reref._data[..., ch_reref, :] + ref_data,
+            1e-6,
+            atol=1e-15,
+        )
+
+
 @testing.requires_testing_data
 @pytest.mark.parametrize("inst_type", ("raw", "epochs", "evoked"))
 def test_set_bipolar_reference(inst_type):
@@ -638,7 +792,7 @@ def test_add_reference():
         preload=True,
         proj="delayed",
     )
-    with pytest.warns(RuntimeWarning, match="reference channels are ignored"):
+    with pytest.warns(RuntimeWarning, match="for this channel is unknown or ambiguous"):
         epochs_ref = add_reference_channels(epochs, ["M1", "M2"], copy=True)
     assert_equal(epochs_ref._data.shape[1], epochs._data.shape[1] + 2)
     _check_channel_names(epochs_ref, ["M1", "M2"])
@@ -692,7 +846,7 @@ def test_add_reference():
         proj="delayed",
     )
     evoked = epochs.average()
-    with pytest.warns(RuntimeWarning, match="reference channels are ignored"):
+    with pytest.warns(RuntimeWarning, match="for this channel is unknown or ambiguous"):
         evoked_ref = add_reference_channels(evoked, ["M1", "M2"], copy=True)
     assert_equal(evoked_ref.data.shape[0], evoked.data.shape[0] + 2)
     _check_channel_names(evoked_ref, ["M1", "M2"])
@@ -742,7 +896,7 @@ def test_add_reorder(n_ref):
         ctx = nullcontext()
     else:
         assert n_ref == 2
-        ctx = pytest.warns(RuntimeWarning, match="locations of multiple")
+        ctx = pytest.warns(RuntimeWarning, match="this channel is unknown or ambiguous")
     with ctx:
         add_reference_channels(raw, chs, copy=False)
     data = raw.get_data()
