@@ -55,7 +55,7 @@ class _Interp2:
             )
         if isinstance(values, np.ndarray):
             values = [values]
-        if isinstance(values, (list, tuple)):
+        if isinstance(values, list | tuple):
             for v in values:
                 if not (v is None or isinstance(v, np.ndarray)):
                     raise TypeError(
@@ -212,7 +212,7 @@ class _Interp2:
 def _check_store(store):
     if isinstance(store, np.ndarray):
         store = [store]
-    if isinstance(store, (list, tuple)) and all(
+    if isinstance(store, list | tuple) and all(
         isinstance(s, np.ndarray) for s in store
     ):
         store = _Storer(*store)
@@ -318,15 +318,9 @@ class _COLA:
         sfreq = float(sfreq)
         pl = "s" if len(self.starts) != 1 else ""
         logger.info(
-            "    Processing %4d data chunk%s of (at least) %0.1f s "
-            "with %0.1f s overlap and %s windowing"
-            % (
-                len(self.starts),
-                pl,
-                self._n_samples / sfreq,
-                self._n_overlap / sfreq,
-                window_name,
-            )
+            f"    Processing {len(self.starts):4d} data chunk{pl} of (at least) "
+            f"{self._n_samples / sfreq:0.1f} s with "
+            f"{self._n_overlap / sfreq:0.1f} s overlap and {window_name} windowing"
         )
         del window, window_name
         if delta > 0:
