@@ -230,6 +230,11 @@ def _check_dupes_odict(ch_names, pos):
 def _read_elc(fname, head_size):
     """Read .elc files.
 
+    The `.elc` files are so-called "asa electrode files". ASA here stands for
+    Advances Source Analysis, and is a software package developed and sold by
+    the ANT Neuro company. They provide a device for sensor digitization, called
+    'xensor', which produces the `.elc` files.
+
     Parameters
     ----------
     fname : str
@@ -241,12 +246,12 @@ def _read_elc(fname, head_size):
     Returns
     -------
     montage : instance of DigMontage
-        The montage in [m].
+        The montage units are [m].
     """
     fid_names = ("Nz", "LPA", "RPA")
 
-    ch_names_, pos = [], []
     with open(fname) as fid:
+        # Read units
         # _read_elc does require to detect the units. (see _mgh_or_standard)
         for line in fid:
             if "UnitPosition" in line:
@@ -258,15 +263,33 @@ def _read_elc(fname, head_size):
         for line in fid:
             if "Positions\n" in line:
                 break
+
+        # Read positions
+        new_style = False
         pos = []
         for line in fid:
             if "Labels\n" in line:
                 break
-            pos.append(list(map(float, line.split())))
+            if ":" in line:
+                # Of the 'new' format: `E01 : 5.288 -3.658 119.693`
+                pos.append(list(map(float, line.split(":")[1].split())))
+                new_style = True
+            else:
+                # Of the 'old' format: `5.288 -3.658 119.693`
+                pos.append(list(map(float, line.split())))
+
+        # Read labels
+        ch_names_ = []
         for line in fid:
             if not line or not set(line) - {" "}:
                 break
-            ch_names_.append(line.strip(" ").strip("\n"))
+            if new_style:
+                # Not sure how this format would deal with spaces in channel labels,
+                # but none of my test files had this, so let's wait until it comes up.
+                parsed = line.strip(" ").strip("\n").split()
+            else:
+                parsed = [line.strip(" ").strip("\n")]
+            ch_names_.extend(parsed)
 
     pos = np.array(pos) * scale
     if head_size is not None:
