@@ -103,13 +103,9 @@ class Layout:
             raise ValueError("Unknown layout type. Should be of type .lout or .lay.")
 
         for ii in range(x.shape[0]):
-            out_str += "%03d %8.2f %8.2f %8.2f %8.2f %s\n" % (
-                self.ids[ii],
-                x[ii],
-                y[ii],
-                width[ii],
-                height[ii],
-                self.names[ii],
+            out_str += (
+                f"{self.ids[ii]:03d} {x[ii]:8.2f} {y[ii]:8.2f} "
+                f"{width[ii]:8.2f} {height[ii]:8.2f} {self.names[ii]}\n"
             )
 
         f = open(fname, "w")
@@ -189,7 +185,7 @@ class Layout:
                 picks = [_ensure_int(picks)]
             except TypeError:
                 picks = (
-                    list(picks) if isinstance(picks, (tuple, set)) else deepcopy(picks)
+                    list(picks) if isinstance(picks, tuple | set) else deepcopy(picks)
                 )
             apply_exclude = False
         if apply_exclude:
@@ -201,13 +197,13 @@ class Layout:
                 except TypeError:
                     exclude = (
                         list(exclude)
-                        if isinstance(exclude, (tuple, set))
+                        if isinstance(exclude, tuple | set)
                         else deepcopy(exclude)
                     )
         for var, var_name in ((picks, "picks"), (exclude, "exclude")):
             if var_name == "exclude" and not apply_exclude:
                 continue
-            if not isinstance(var, (list, tuple, set, np.ndarray)):
+            if not isinstance(var, list | tuple | set | np.ndarray):
                 raise TypeError(
                     f"'{var_name}' must be a list, tuple, set or ndarray. "
                     f"Got {type(var)} instead."
@@ -623,7 +619,7 @@ def find_layout(info, ch_type=None, exclude="bads"):
     elif (has_eeg_coils_only and ch_type in [None, "eeg"]) or (
         has_eeg_coils_and_meg and ch_type == "eeg"
     ):
-        if not isinstance(info, (dict, Info)):
+        if not isinstance(info, dict | Info):
             raise RuntimeError(
                 "Cannot make EEG layout, no measurement info "
                 "was passed to `find_layout`"
@@ -945,14 +941,13 @@ def _auto_topomap_coords(info, picks, ignore_overlap, to_sphere, sphere):
         if len(locs3d) == 0:
             raise RuntimeError(
                 "Did not find any digitization points of "
-                "kind FIFFV_POINT_EEG (%d) in the info." % FIFF.FIFFV_POINT_EEG
+                f"kind {FIFF.FIFFV_POINT_EEG} in the info."
             )
 
         if len(locs3d) != len(eeg_ch_names):
             raise ValueError(
-                "Number of EEG digitization points (%d) "
-                "doesn't match the number of EEG channels "
-                "(%d)" % (len(locs3d), len(eeg_ch_names))
+                f"Number of EEG digitization points ({len(locs3d)}) doesn't match the "
+                f"number of EEG channels ({len(eeg_ch_names)})"
             )
 
         # We no longer center digitization points on head origin, as we work
