@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 r"""Browse raw data.
 
 This uses :func:`mne.io.read_raw` so it supports the same formats
@@ -13,7 +12,7 @@ Examples
                      --eve sample_audvis_raw-eve.fif
 """
 
-# Authors : Eric Larson, PhD
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -77,7 +76,7 @@ def run():
         "-o",
         "--order",
         dest="group_by",
-        help="Order to use for grouping during plotting " "('type' or 'original')",
+        help="Order to use for grouping during plotting ('type' or 'original')",
         default="type",
     )
     parser.add_option(
@@ -136,6 +135,13 @@ def run():
         default=None,
         action="store_true",
     )
+    parser.add_option(
+        "--butterfly",
+        dest="butterfly",
+        help="Plot in butterfly mode",
+        default=False,
+        action="store_true",
+    )
     _add_verbose_flag(parser)
     options, args = parser.parse_args()
 
@@ -167,6 +173,7 @@ def run():
                 pass
     filterchpi = options.filterchpi
     verbose = options.verbose
+    butterfly = options.butterfly
 
     if raw_in is None:
         parser.print_help()
@@ -202,6 +209,7 @@ def run():
         lowpass=lowpass,
         filtorder=filtorder,
         clipping=clipping,
+        butterfly=butterfly,
         proj=not proj_off,
         verbose=verbose,
         show=True,
