@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 """View the 3-Layers BEM model using Freeview.
 
 Examples
@@ -8,7 +7,8 @@ Examples
     $ mne freeview_bem_surfaces -s sample
 
 """
-# Authors:  Alexandre Gramfort <alexandre.gramfort@inria.fr>
+
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -20,7 +20,7 @@ import mne
 from mne.utils import get_subjects_dir, run_subprocess
 
 
-def freeview_bem_surfaces(subject, subjects_dir, method):
+def freeview_bem_surfaces(subject, subjects_dir, method=None):
     """View 3-Layers BEM model with Freeview.
 
     Parameters
@@ -29,8 +29,9 @@ def freeview_bem_surfaces(subject, subjects_dir, method):
         Subject name
     subjects_dir : path-like
         Directory containing subjects data (Freesurfer SUBJECTS_DIR)
-    method : str
-        Can be ``'flash'`` or ``'watershed'``.
+    method : str | None
+        Can be ``'flash'`` or ``'watershed'``, or None to use the ``bem/`` directory
+        files.
     """
     subjects_dir = str(get_subjects_dir(subjects_dir, raise_error=True))
 
@@ -57,9 +58,9 @@ def freeview_bem_surfaces(subject, subjects_dir, method):
 
     if method == "watershed":
         bem_dir = op.join(bem_dir, "watershed")
-        outer_skin = op.join(bem_dir, "%s_outer_skin_surface" % subject)
-        outer_skull = op.join(bem_dir, "%s_outer_skull_surface" % subject)
-        inner_skull = op.join(bem_dir, "%s_inner_skull_surface" % subject)
+        outer_skin = op.join(bem_dir, f"{subject}_outer_skin_surface")
+        outer_skull = op.join(bem_dir, f"{subject}_outer_skull_surface")
+        inner_skull = op.join(bem_dir, f"{subject}_inner_skull_surface")
     else:
         if method == "flash":
             bem_dir = op.join(bem_dir, "flash")
@@ -70,9 +71,9 @@ def freeview_bem_surfaces(subject, subjects_dir, method):
     # put together the command
     cmd = ["freeview"]
     cmd += ["--volume", mri]
-    cmd += ["--surface", "%s:color=red:edgecolor=red" % inner_skull]
-    cmd += ["--surface", "%s:color=yellow:edgecolor=yellow" % outer_skull]
-    cmd += ["--surface", "%s:color=255,170,127:edgecolor=255,170,127" % outer_skin]
+    cmd += ["--surface", f"{inner_skull}:color=red:edgecolor=red"]
+    cmd += ["--surface", f"{outer_skull}:color=yellow:edgecolor=yellow"]
+    cmd += ["--surface", f"{outer_skin}:color=255,170,127:edgecolor=255,170,127"]
 
     run_subprocess(cmd, env=env, stdout=sys.stdout)
     print("[done]")
@@ -85,10 +86,6 @@ def run():
     parser = get_optparser(__file__)
 
     subject = os.environ.get("SUBJECT")
-    subjects_dir = get_subjects_dir()
-    if subjects_dir is not None:
-        subjects_dir = str(subjects_dir)
-
     parser.add_option(
         "-s", "--subject", dest="subject", help="Subject name", default=subject
     )
@@ -97,13 +94,12 @@ def run():
         "--subjects-dir",
         dest="subjects_dir",
         help="Subjects directory",
-        default=subjects_dir,
     )
     parser.add_option(
         "-m",
         "--method",
         dest="method",
-        help=("Method used to generate the BEM model. " "Can be flash or watershed."),
+        help="Method used to generate the BEM model. Can be flash or watershed.",
     )
 
     options, args = parser.parse_args()
