@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 """Show measurement info from .fif file.
 
 Examples
@@ -9,7 +8,7 @@ Examples
 
 """
 
-# Authors : Alexandre Gramfort, Ph.D.
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -29,10 +28,10 @@ def run():
     fname = args[0]
 
     if not fname.endswith(".fif"):
-        raise ValueError("%s does not seem to be a .fif file." % fname)
+        raise ValueError(f"{fname} does not seem to be a .fif file.")
 
     info = mne.io.read_info(fname)
-    print("File : %s" % fname)
+    print(f"File : {fname}")
     print(info)
 
 
