@@ -5,15 +5,15 @@
 from collections import Counter
 
 import numpy as np
+from sklearn.base import BaseEstimator, TransformerMixin
 
 from .._fiff.pick import _picks_to_idx, pick_info, pick_types
 from ..parallel import parallel_func
 from ..utils import logger, verbose
 from .base import _set_cv
-from .mixin import EstimatorMixin, TransformerMixin
 
 
-class EMS(TransformerMixin, EstimatorMixin):
+class EMS(TransformerMixin, BaseEstimator):
     """Transformer to compute event-matched spatial filters.
 
     This version of EMS :footcite:`SchurgerEtAl2013` operates on the entire
