@@ -5,17 +5,18 @@
 import logging
 
 import numpy as np
-from scipy.sparse import issparse
+from sklearn.base import BaseEstimator, MetaEstimatorMixin, TransformerMixin, clone
+from sklearn.metrics import check_scoring
+from sklearn.preprocessing import LabelEncoder
+from sklearn.utils import check_array
 
-from ..fixes import _get_check_scoring
 from ..parallel import parallel_func
 from ..utils import ProgressBar, _parse_verbose, array_split_idx, fill_doc, verbose
-from .base import BaseEstimator, _check_estimator
-from .mixin import TransformerMixin
+from .base import _check_estimator
 
 
 @fill_doc
-class SlidingEstimator(BaseEstimator, TransformerMixin):
+class SlidingEstimator(MetaEstimatorMixin, TransformerMixin, BaseEstimator):
     """Search Light.
 
     Fit, predict and score a series of models to each subset of the dataset
@@ -56,13 +57,24 @@ class SlidingEstimator(BaseEstimator, TransformerMixin):
         self.allow_2d = allow_2d
         self.verbose = verbose
 
-    def _more_tags(self):
-        return {"no_validation": True, "requires_fit": False}
-
     @property
     def _estimator_type(self):
         return getattr(self.base_estimator, "_estimator_type", None)
 
+    def __sklearn_tags__(self):
+        """Get sklearn tags."""
+        from sklearn.utils import get_tags
+
+        tags = super().__sklearn_tags__()
+        sub_tags = get_tags(self.base_estimator)
+        tags.estimator_type = sub_tags.estimator_type
+        for kind in ("classifier", "regressor", "transformer"):
+            if tags.estimator_type == kind:
+                attr = f"{kind}_tags"
+                setattr(tags, attr, getattr(sub_tags, attr))
+                break
+        return tags
+
     def __repr__(self):  # noqa: D105
         repr_str = "<" + super().__repr__()
         if hasattr(self, "estimators_"):
@@ -256,14 +268,9 @@ class SlidingEstimator(BaseEstimator, TransformerMixin):
     def _check_Xy(self, X, y=None):
         """Aux. function to check input data."""
         # Once we require sklearn 1.1+ we should do something like:
-        # from sklearn.utils import check_array
-        # X = check_array(X, ensure_2d=False, input_name="X")
-        # y = check_array(y, dtype=None, ensure_2d=False, input_name="y")
-        if issparse(X):
-            raise TypeError("X should be a dense array, got sparse instead.")
-        X = np.asarray(X)
+        X = check_array(X, ensure_2d=False, allow_nd=True, input_name="X")
         if y is not None:
-            y = np.asarray(y)
+            y = check_array(y, dtype=None, ensure_2d=False, input_name="y")
             if len(X) != len(y) or len(y) < 1:
                 raise ValueError("X and y must have the same length.")
         if X.ndim < 3:
@@ -300,8 +307,6 @@ class SlidingEstimator(BaseEstimator, TransformerMixin):
         score : array, shape (n_samples, n_estimators)
             Score for each estimator/task.
         """  # noqa: E501
-        check_scoring = _get_check_scoring()
-
         X = self._check_Xy(X, y)
         if X.shape[-1] != len(self.estimators_):
             raise ValueError("The number of estimators does not match X.shape[-1]")
@@ -357,8 +362,6 @@ def _sl_fit(estimator, X, y, pb, **fit_params):
     estimators_ : list of estimators
         The fitted estimators.
     """
-    from sklearn.base import clone
-
     estimators_ = list()
     for ii in range(X.shape[-1]):
         est = clone(estimator)
@@ -600,7 +603,6 @@ class GeneralizingEstimator(SlidingEstimator):
         score : array, shape (n_samples, n_estimators, n_slices)
             Score for each estimator / data slice couple.
         """  # noqa: E501
-        check_scoring = _get_check_scoring()
         X = self._check_Xy(X, y)
         # For predictions/transforms the parallelization is across the data and
         # not across the estimators to avoid memory load.
@@ -719,8 +721,6 @@ def _gl_score(estimators, scoring, X, y, pb):
 
 
 def _fix_auc(scoring, y):
-    from sklearn.preprocessing import LabelEncoder
-
     # This fixes sklearn's inability to compute roc_auc when y not in [0, 1]
     # scikit-learn/scikit-learn#6874
     if scoring is not None:
