@@ -4,12 +4,12 @@
 
 import numpy as np
 from scipy.linalg import eigh
+from sklearn.base import BaseEstimator, TransformerMixin
 
 from .._fiff.pick import _picks_to_idx
 from ..cov import Covariance, _regularized_covariance
 from ..defaults import _handle_default
 from ..filter import filter_data
-from ..fixes import BaseEstimator
 from ..rank import compute_rank
 from ..time_frequency import psd_array_welch
 from ..utils import (
@@ -20,11 +20,10 @@ from ..utils import (
     fill_doc,
     logger,
 )
-from .mixin import TransformerMixin
 
 
 @fill_doc
-class SSD(BaseEstimator, TransformerMixin):
+class SSD(TransformerMixin, BaseEstimator):
     """
     Signal decomposition using the Spatio-Spectral Decomposition (SSD).
 
@@ -113,7 +112,7 @@ class SSD(BaseEstimator, TransformerMixin):
                     f"{param + '_freq'} must be defined in filter parameters for {key}"
                 )
             val = dicts[key][param + "_freq"]
-            if not isinstance(val, (int, float)):
+            if not isinstance(val, int | float):
                 _validate_type(val, ("numeric",), f"{key} {param}_freq")
         # check freq bands
         if (
@@ -125,14 +124,8 @@ class SSD(BaseEstimator, TransformerMixin):
                 "The signal band-pass must be within the noise "
                 "band-pass!"
             )
-        self.picks_ = _picks_to_idx(info, picks, none="data", exclude="bads")
+        self.picks = picks
         del picks
-        ch_types = info.get_channel_types(picks=self.picks_, unique=True)
-        if len(ch_types) > 1:
-            raise ValueError(
-                "At this point SSD only supports fitting "
-                "single channel types. Your info has %i types" % (len(ch_types))
-            )
         self.info = info
         self.freqs_signal = (filt_params_signal["l_freq"], filt_params_signal["h_freq"])
         self.freqs_noise = (filt_params_noise["l_freq"], filt_params_noise["h_freq"])
@@ -163,7 +156,7 @@ class SSD(BaseEstimator, TransformerMixin):
         if n_chan != self.info["nchan"]:
             raise ValueError(
                 "Info must match the input data."
-                "Found %i channels but expected %i." % (n_chan, self.info["nchan"])
+                f"Found {n_chan} channels but expected {self.info['nchan']}."
             )
 
     def fit(self, X, y=None):
@@ -183,6 +176,13 @@ class SSD(BaseEstimator, TransformerMixin):
         self : instance of SSD
             Returns the modified instance.
         """
+        ch_types = self.info.get_channel_types(picks=self.picks, unique=True)
+        if len(ch_types) > 1:
+            raise ValueError(
+                "At this point SSD only supports fitting "
+                f"single channel types. Your info has {len(ch_types)} types."
+            )
+        self.picks_ = _picks_to_idx(self.info, self.picks, none="data", exclude="bads")
         self._check_X(X)
         X_aux = X[..., self.picks_, :]
 
@@ -261,6 +261,31 @@ class SSD(BaseEstimator, TransformerMixin):
             X_ssd = X_ssd[:, self.sorter_spec, :][:, : self.n_components, :]
         return X_ssd
 
+    def fit_transform(self, X, y=None, **fit_params):
+        """Fit SSD to data, then transform it.
+
+        Fits transformer to ``X`` and ``y`` with optional parameters ``fit_params``, and
+        returns a transformed version of ``X``.
+
+        Parameters
+        ----------
+        X : array, shape ([n_epochs, ]n_channels, n_times)
+            The input data from which to estimate the SSD. Either 2D array obtained from
+            continuous data or 3D array obtained from epoched data.
+        y : None
+            Ignored; exists for compatibility with scikit-learn pipelines.
+        **fit_params : dict
+            Additional fitting parameters passed to the :meth:`mne.decoding.SSD.fit`
+            method. Not used for this class.
+
+        Returns
+        -------
+        X_ssd : array, shape ([n_epochs, ]n_components, n_times)
+            The processed data.
+        """
+        # use parent TransformerMixin method but with custom docstring
+        return super().fit_transform(X, y=y, **fit_params)
+
     def get_spectral_ratio(self, ssd_sources):
         """Get the spectal signal-to-noise ratio for each spatial filter.
 
@@ -380,15 +405,13 @@ def _dimensionality_reduction(cov_signal, cov_noise, info, rank):
             eigvects[:, :rank], np.eye(rank) * (eigvals[:rank] ** -0.5)
         )
         logger.info(
-            "Projecting covariance of %i channels to %i rank subspace"
-            % (
-                n_channels,
-                rank,
-            )
+            "Projecting covariance of %i channels to %i rank subspace",
+            n_channels,
+            rank,
         )
     else:
         rank_proj = np.eye(n_channels)
-        logger.info("Preserving covariance rank (%i)" % (rank,))
+        logger.info("Preserving covariance rank (%i)", rank)
 
     # project covariance matrices to rank subspace
     cov_signal = np.matmul(rank_proj.T, np.matmul(cov_signal, rank_proj))
