@@ -3,11 +3,10 @@
 # Copyright the MNE-Python contributors.
 
 import numpy as np
+from sklearn.base import BaseEstimator, TransformerMixin
 
 from ..time_frequency.tfr import _compute_tfr
 from ..utils import _check_option, fill_doc, verbose
-from .base import BaseEstimator
-from .mixin import TransformerMixin
 
 
 @fill_doc
