@@ -64,8 +64,8 @@ DEFAULTS = dict(
         whitened="Z",
         gsr="S",
         temperature="C",
-        eyegaze="AU",
-        pupil="AU",
+        eyegaze="rad",
+        pupil="m",
     ),
     units=dict(
         mag="fT",
@@ -92,8 +92,8 @@ DEFAULTS = dict(
         whitened="Z",
         gsr="S",
         temperature="C",
-        eyegaze="AU",
-        pupil="AU",
+        eyegaze="rad",
+        pupil="µm",
     ),
     # scalings for the units
     scalings=dict(
@@ -122,7 +122,7 @@ DEFAULTS = dict(
         gsr=1.0,
         temperature=1.0,
         eyegaze=1.0,
-        pupil=1.0,
+        pupil=1e6,
     ),
     # rough guess for a good plot
     scalings_plot_raw=dict(
@@ -156,8 +156,8 @@ DEFAULTS = dict(
         gof=1e2,
         gsr=1.0,
         temperature=0.1,
-        eyegaze=3e-1,
-        pupil=1e3,
+        eyegaze=2e-1,
+        pupil=1e-2,
     ),
     scalings_cov_rank=dict(
         mag=1e12,
@@ -183,8 +183,8 @@ DEFAULTS = dict(
         hbo=(0, 20),
         hbr=(0, 20),
         csd=(-50.0, 50.0),
-        eyegaze=(0.0, 5000.0),
-        pupil=(0.0, 5000.0),
+        eyegaze=(-1, 1),
+        pupil=(-1.0, 1.0),
     ),
     titles=dict(
         mag="Magnetometers",
