@@ -176,7 +176,7 @@ class Evoked(
     ):
         _validate_type(proj, bool, "'proj'")
         # Read the requested data
-        fname = str(_check_fname(fname=fname, must_exist=True, overwrite="read"))
+        fname = _check_fname(fname=fname, must_exist=True, overwrite="read")
         (
             self.info,
             self.nave,
@@ -197,6 +197,18 @@ class Evoked(
             self.apply_proj()
         self.filename = fname
 
+    @property
+    def filename(self) -> Path | None:
+        """The filename of the evoked object, if it exists.
+
+        :type: :class:`~pathlib.Path` | None
+        """
+        return self._filename
+
+    @filename.setter
+    def filename(self, value):
+        self._filename = Path(value) if value is not None else value
+
     @property
     def kind(self):
         """The data kind."""
@@ -603,7 +615,8 @@ class Evoked(
         exclude="bads",
         show=True,
     ):
-        """
+        """.
+
         Notes
         -----
         .. versionadded:: 0.10.0
@@ -1481,6 +1494,7 @@ class EvokedArray(Evoked):
         self.baseline = baseline
         if self.baseline is not None:  # omit log msg if not baselining
             self.apply_baseline(self.baseline)
+        self._filename = None
 
 
 def _get_entries(fid, evoked_node, allow_maxshield=False):
@@ -1562,7 +1576,7 @@ def combine_evoked(all_evoked, weights):
 
     .. Warning::
         Other than cases like simple subtraction mentioned above (where all
-        weights are -1 or 1), if you provide numeric weights instead of using
+        weights are ``-1`` or ``1``), if you provide numeric weights instead of using
         ``'equal'`` or ``'nave'``, the resulting `~mne.Evoked` object's
         ``.nave`` attribute (which is used to scale noise covariance when
         applying the inverse operator) may not be suitable for inverse imaging.
@@ -1571,7 +1585,7 @@ def combine_evoked(all_evoked, weights):
     ----------
     all_evoked : list of Evoked
         The evoked datasets.
-    weights : list of float | 'equal' | 'nave'
+    weights : list of float | ``'equal'`` | ``'nave'``
         The weights to apply to the data of each evoked instance, or a string
         describing the weighting strategy to apply: ``'nave'`` computes
         sum-to-one weights proportional to each object's ``nave`` attribute;
@@ -1681,7 +1695,7 @@ def read_evokeds(
                   baseline correction, but merely omit the optional, additional
                   baseline correction.
     kind : str
-        Either 'average' or 'standard_error', the type of data to read.
+        Either ``'average'`` or ``'standard_error'``, the type of data to read.
     proj : bool
         If False, available projectors won't be applied to the data.
     allow_maxshield : bool | str (default False)
@@ -1689,7 +1703,7 @@ def read_evokeds(
         active compensation (MaxShield). Data recorded with MaxShield should
         generally not be loaded directly, but should first be processed using
         SSS/tSSS to remove the compensation signals that may also affect brain
-        activity. Can also be "yes" to load without eliciting a warning.
+        activity. Can also be ``"yes"`` to load without eliciting a warning.
     %(verbose)s
 
     Returns
@@ -1710,7 +1724,7 @@ def read_evokeds(
         saving, this will be reflected in their ``baseline`` attribute after
         reading.
     """
-    fname = str(_check_fname(fname, overwrite="read", must_exist=True))
+    fname = _check_fname(fname, overwrite="read", must_exist=True)
     check_fname(fname, "evoked", ("-ave.fif", "-ave.fif.gz", "_ave.fif", "_ave.fif.gz"))
     logger.info(f"Reading {fname} ...")
     return_list = True
@@ -1990,7 +2004,7 @@ def _write_evokeds(fname, evoked, check=True, *, on_mismatch="raise", overwrite=
             fname, "evoked", ("-ave.fif", "-ave.fif.gz", "_ave.fif", "_ave.fif.gz")
         )
 
-    if not isinstance(evoked, (list, tuple)):
+    if not isinstance(evoked, list | tuple):
         evoked = [evoked]
 
     warned = False
