@@ -3,7 +3,7 @@
 # Copyright the MNE-Python contributors.
 
 import datetime as dt
-from typing import Callable
+from collections.abc import Callable
 
 import numpy as np
 
@@ -138,6 +138,8 @@ def _export_raw(fname, raw, physical_range, add_ch_type):
         if physical_range == "auto":  # per channel type
             pmin = ch_types_phys_min[ch_type]
             pmax = ch_types_phys_max[ch_type]
+            if pmax == pmin:
+                pmax = pmin + 1
             prange = pmin, pmax
 
         signals.append(
