@@ -1,5 +1,4 @@
-# Authors: Eric Larson <larson.eric.d@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -92,7 +91,7 @@ def test_read_ctf(tmp_path):
             args = (
                 str(ch_num + 1),
                 raw.ch_names[ch_num],
-            ) + tuple("%0.5f" % x for x in 100 * pos[ii])  # convert to cm
+            ) + tuple(f"{x:0.5f}" for x in 100 * pos[ii])  # convert to cm
             fid.write(("\t".join(args) + "\n").encode("ascii"))
     pos_read_old = np.array([raw.info["chs"][p]["loc"][:3] for p in picks])
     with pytest.warns(RuntimeWarning, match="RMSP .* changed to a MISC ch"):
@@ -210,7 +209,7 @@ def test_read_ctf(tmp_path):
                     c2[key],
                     atol=1e-6,
                     rtol=1e-4,
-                    err_msg='raw.info["chs"][%d][%s]' % (ii, key),
+                    err_msg=f'raw.info["chs"][{ii}][{key}]',
                 )
             # XXX 2016/02/24: fixed bug with normal computation that used
             # to exist, once mne-C tools are updated we should update our FIF
@@ -228,7 +227,7 @@ def test_read_ctf(tmp_path):
                     check,
                     atol=1e-6,
                     rtol=1e-4,
-                    err_msg='raw.info["chs"][%d][%s]' % (ii, key),
+                    err_msg=f'raw.info["chs"][{ii}][{key}]',
                 )
                 if (c2[key][3:] == 0.0).all():
                     check = [np.nan] * 3
@@ -239,7 +238,7 @@ def test_read_ctf(tmp_path):
                     check,
                     atol=1e-6,
                     rtol=1e-4,
-                    err_msg='raw.info["chs"][%d][%s]' % (ii, key),
+                    err_msg=f'raw.info["chs"][{ii}][{key}]',
                 )
 
         # Make sure all digitization points are in the MNE head coord frame
