@@ -1,10 +1,4 @@
-# Authors: Teon Brooks <teon.brooks@gmail.com>
-#          Martin Billinger <martin.billinger@tugraz.at>
-#          Alan Leggitt <alan.leggitt@ucsf.edu>
-#          Alexandre Barachant <alexandre.barachant@gmail.com>
-#          Stefan Appelhoff <stefan.appelhoff@mailbox.org>
-#          Joan Massich <mailsik@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -51,8 +45,6 @@ edf_path = data_dir / "test.edf"
 duplicate_channel_labels_path = data_dir / "duplicate_channel_labels.edf"
 edf_uneven_path = data_dir / "test_uneven_samp.edf"
 bdf_eeglab_path = data_dir / "test_bdf_eeglab.mat"
-edf_eeglab_path = data_dir / "test_edf_eeglab.mat"
-edf_uneven_eeglab_path = data_dir / "test_uneven_samp.mat"
 edf_stim_channel_path = data_dir / "test_edf_stim_channel.edf"
 edf_txt_stim_channel_path = data_dir / "test_edf_stim_channel.txt"
 
@@ -100,7 +92,7 @@ def test_orig_units():
 def test_units_params():
     """Test enforcing original channel units."""
     with pytest.raises(
-        ValueError, match=r"Unit for channel .* is present .* cannot " "overwrite it"
+        ValueError, match=r"Unit for channel .* is present .* cannot overwrite it"
     ):
         _ = read_raw_edf(edf_path, units="V", preload=True)
 
@@ -131,24 +123,12 @@ def test_subject_info(tmp_path):
     want = {
         "his_id": "X",
         "sex": 1,
-        "birthday": (1967, 10, 9),
+        "birthday": datetime.date(1967, 10, 9),
         "last_name": "X",
     }
     for key, val in want.items():
         assert raw.info["subject_info"][key] == val, key
 
-    # check "subject_info" from `_raw_extras`
-    edf_info = raw._raw_extras[0]
-    assert edf_info["subject_info"] is not None
-    want = {
-        "id": "X",
-        "sex": "M",
-        "birthday": datetime.datetime(1967, 10, 9, 0, 0),
-        "name": "X",
-    }
-    for key, val in want.items():
-        assert edf_info["subject_info"][key] == val, key
-
     # add information
     raw.info["subject_info"]["hand"] = 0
 
@@ -162,7 +142,7 @@ def test_subject_info(tmp_path):
     want = {
         "his_id": "X",
         "sex": 1,
-        "birthday": (1967, 10, 9),
+        "birthday": datetime.date(1967, 10, 9),
         "last_name": "X",
         "hand": 0,
     }
@@ -888,7 +868,7 @@ def test_invalid_date(tmp_path):
     edf[172] = ord("2")
     with open(fname, "wb") as f:
         f.write(edf)
-    with pytest.warns(RuntimeWarning, match="Invalid date"):
+    with pytest.warns(RuntimeWarning, match="Invalid measurement date"):
         read_raw_edf(fname)
 
     # another invalid date 29.00.14 (0 is not a month)
@@ -896,7 +876,7 @@ def test_invalid_date(tmp_path):
     edf[172] = ord("0")
     with open(fname, "wb") as f:
         f.write(edf)
-    with pytest.warns(RuntimeWarning, match="Invalid date"):
+    with pytest.warns(RuntimeWarning, match="Invalid measurement date"):
         read_raw_edf(fname)
 
 
@@ -1013,9 +993,8 @@ def test_include():
     raw = read_raw_edf(edf_path, include="I[1-4]")
     assert sorted(raw.ch_names) == ["I1", "I2", "I3", "I4"]
 
-    with pytest.raises(ValueError) as e:
+    with pytest.raises(ValueError, match="'exclude' must be empty if 'include' is "):
         raw = read_raw_edf(edf_path, include=["I1", "I2"], exclude="I[1-4]")
-        assert str(e.value) == "'exclude' must be empty" "if 'include' is assigned."
 
 
 @pytest.mark.parametrize(
@@ -1198,3 +1177,16 @@ def test_ch_types():
     raw = read_raw_edf(edf_chtypes_path, units="uV")  # should be okay
     data_units = raw.get_data()
     assert_allclose(data, data_units)
+
+
+@testing.requires_testing_data
+def test_anonymization():
+    """Test that RawEDF anonymizes data in memory."""
+    # gh-11966
+    raw = read_raw_edf(edf_stim_resamp_path)
+    for key in ("meas_date", "subject_info"):
+        assert key not in raw._raw_extras[0]
+    bday = raw.info["subject_info"]["birthday"]
+    assert bday == datetime.date(1967, 10, 9)
+    raw.anonymize()
+    assert raw.info["subject_info"]["birthday"] != bday
