@@ -141,8 +141,8 @@ def _read_mff_header(filepath):
             n_chans = n_chans + 1
     if n_chans != summaryinfo["n_channels"]:
         raise RuntimeError(
-            "Number of defined channels (%d) did not match the "
-            "expected channels (%d)" % (n_chans, summaryinfo["n_channels"])
+            f"Number of defined channels ({n_chans}) did not match the "
+            f"expected channels ({summaryinfo['n_channels']})."
         )
 
     # Check presence of PNS data
@@ -354,7 +354,7 @@ def _read_raw_egi_mff(
     preload=False,
     channel_naming="E%d",
     *,
-    events_as_annotations=False,
+    events_as_annotations=True,
     verbose=None,
 ):
     """Read EGI mff binary as raw object."""
@@ -541,13 +541,10 @@ class RawMff(BaseRaw):
                 annot["description"].append("BAD_EGI_PSG")
             elif pns_samples != eeg_samples:
                 raise RuntimeError(
-                    "PNS samples (%d) did not match EEG samples (%d)"
-                    % (pns_samples, eeg_samples)
+                    f"PNS samples ({pns_samples}) did not match EEG samples "
+                    f"({eeg_samples})."
                 )
 
-        self._filenames = [file_bin]
-        self._raw_extras = [egi_info]
-
         super().__init__(
             info,
             preload=preload,
@@ -636,7 +633,7 @@ class RawMff(BaseRaw):
         # TODO: Refactor this reading with the PNS reading in a single function
         # (DRY)
         samples_to_read = stop - start
-        with open(self._filenames[fi], "rb", buffering=0) as fid:
+        with open(self.filenames[fi], "rb", buffering=0) as fid:
             # Go to starting block
             current_block = 0
             current_block_info = None
