@@ -3,8 +3,8 @@
 # Copyright the MNE-Python contributors.
 
 import copy
-import os
 import os.path as op
+from pathlib import Path
 
 import numpy as np
 
@@ -73,9 +73,12 @@ class Raw(BaseRaw):
         Time vector in seconds. Starts from 0, independently of `first_samp`
         value. Time interval between consecutive time samples is equal to the
         inverse of the sampling frequency.
+    duration : float
+        The duration of the raw file in seconds.
+
+        .. versionadded:: 1.9
     preload : bool
         Indicates whether raw data are in memory.
-    %(verbose)s
     """
 
     _extra_attributes = (
@@ -114,20 +117,32 @@ class Raw(BaseRaw):
                     )
                     _on_missing(on_split_missing, msg, name="on_split_missing")
                     break
-        if _file_like(fname):
-            # avoid serialization error when copying file-like
-            fname = None  # noqa
+        # If using a file-like object, we need to be careful about serialization and
+        # types.
+        #
+        # 1. We must change both the variable named "fname" here so that _get_argvalues
+        #    (magic) does not store the file-like object.
+        # 2. We need to ensure "filenames" passed to the constructor below gets a list
+        #    of Path or None.
+        # 3. We need to remove the file-like objects from _raw_extras. This must
+        #    be done *after* the super().__init__ call, because the constructor
+        #    needs the file-like objects to read the data (which it will do because we
+        #    force preloading for file-like objects).
+
+        # Avoid file-like in _get_argvalues (1)
+        fname = _path_from_fname(fname)
 
         _check_raw_compatibility(raws)
         super().__init__(
             copy.deepcopy(raws[0].info),
-            False,
-            [r.first_samp for r in raws],
-            [r.last_samp for r in raws],
-            [r.filename for r in raws],
-            [r._raw_extras for r in raws],
-            raws[0].orig_format,
-            None,
+            preload=False,
+            first_samps=[r.first_samp for r in raws],
+            last_samps=[r.last_samp for r in raws],
+            # Avoid file-like objects in raw.filenames (2)
+            filenames=[_path_from_fname(r._raw_extras["filename"]) for r in raws],
+            raw_extras=[r._raw_extras for r in raws],
+            orig_format=raws[0].orig_format,
+            dtype=None,
             buffer_size_sec=buffer_size_sec,
             verbose=verbose,
         )
@@ -154,9 +169,10 @@ class Raw(BaseRaw):
             self._preload_data(preload)
         else:
             self.preload = False
-        # If using a file-like object, fix the filenames to be representative
-        # strings now instead of the file-like objects
-        self._filenames = [_get_fname_rep(fname) for fname in self._filenames]
+        # Avoid file-like objects in _raw_extras (3)
+        for extra in self._raw_extras:
+            if not isinstance(extra["filename"], Path):
+                extra["filename"] = None
 
     @verbose
     def _read_raw_file(
@@ -179,16 +195,13 @@ class Raw(BaseRaw):
                 endings += tuple([f"{e}.gz" for e in endings])
                 check_fname(fname, "raw", endings)
             # filename
-            fname = str(_check_fname(fname, "read", True, "fname"))
-            ext = os.path.splitext(fname)[1].lower()
-            whole_file = preload if ".gz" in ext else False
-            del ext
+            fname = _check_fname(fname, "read", True, "fname")
+            whole_file = preload if fname.suffix == ".gz" else False
         else:
             # file-like
             if not preload:
                 raise ValueError("preload must be used with file-like objects")
             whole_file = True
-        fname_rep = _get_fname_rep(fname)
         ff, tree, _ = fiff_open(fname, preload=whole_file)
         with ff as fid:
             #   Read the measurement info
@@ -203,7 +216,7 @@ class Raw(BaseRaw):
                 if len(raw_node) == 0:
                     raw_node = dir_tree_find(meas, FIFF.FIFFB_IAS_RAW_DATA)
                     if len(raw_node) == 0:
-                        raise ValueError(f"No raw data in {fname_rep}")
+                        raise ValueError(f"No raw data in {_get_fname_rep(fname)}")
                     _check_maxshield(allow_maxshield)
                     with info._unlock():
                         info["maxshield"] = True
@@ -236,7 +249,6 @@ class Raw(BaseRaw):
                 _check_entry(first, nent)
 
             raw = _RawShell()
-            raw.filename = fname
             raw.first_samp = first_samp
             if info["meas_date"] is None and annotations is not None:
                 # we need to adjust annotations.onset as when there is no meas
@@ -318,7 +330,7 @@ class Raw(BaseRaw):
                     tag = read_tag(fid, ent.pos)
                     nskip = int(tag.data.item())
 
-            next_fname = _get_next_fname(fid, fname_rep, tree)
+            next_fname = _get_next_fname(fid, _path_from_fname(fname), tree)
 
         # reformat raw_extras to be a dict of list/ndarray rather than
         # list of dict (faster access)
@@ -338,6 +350,7 @@ class Raw(BaseRaw):
         del raw_extras["first"]
         del raw_extras["last"]
         del raw_extras["nsamp"]
+        raw_extras["filename"] = fname
 
         raw.last_samp = first_samp - 1
         raw.orig_format = orig_format
@@ -350,13 +363,11 @@ class Raw(BaseRaw):
         raw._cals = cals
         raw._raw_extras = raw_extras
         logger.info(
-            "    Range : %d ... %d =  %9.3f ... %9.3f secs"
-            % (
-                raw.first_samp,
-                raw.last_samp,
-                float(raw.first_samp) / info["sfreq"],
-                float(raw.last_samp) / info["sfreq"],
-            )
+            "    Range : %d ... %d =  %9.3f ... %9.3f secs",
+            raw.first_samp,
+            raw.last_samp,
+            float(raw.first_samp) / info["sfreq"],
+            float(raw.last_samp) / info["sfreq"],
         )
 
         raw.info = info
@@ -392,7 +403,7 @@ class Raw(BaseRaw):
     def _read_segment_file(self, data, idx, fi, start, stop, cals, mult):
         """Read a segment of data from a file."""
         n_bad = 0
-        with _fiff_get_fid(self._filenames[fi]) as fid:
+        with _fiff_get_fid(self._raw_extras[fi]["filename"]) as fid:
             bounds = self._raw_extras[fi]["bounds"]
             ents = self._raw_extras[fi]["ent"]
             nchan = self._raw_extras[fi]["orig_nchan"]
@@ -536,3 +547,16 @@ def read_raw_fif(
         verbose=verbose,
         on_split_missing=on_split_missing,
     )
+
+
+def _path_from_fname(fname) -> Path | None:
+    if not isinstance(fname, Path):
+        if isinstance(fname, str):
+            fname = Path(fname)
+        else:
+            # Try to get a filename from the file-like object
+            try:
+                fname = Path(fname.name)
+            except Exception:
+                fname = None
+    return fname
