@@ -50,7 +50,7 @@ def _call_digitization(info, mrk, elp, hsp, kit_info, *, bad_coils=()):
     # prepare mrk
     if isinstance(mrk, list):
         mrk = [
-            read_mrk(marker) if isinstance(marker, (str, Path, PathLike)) else marker
+            read_mrk(marker) if isinstance(marker, str | Path | PathLike) else marker
             for marker in mrk
         ]
         mrk = np.mean(mrk, axis=0)
@@ -210,7 +210,7 @@ class RawKIT(BaseRaw):
         assert n_bytes in (2, 4)
         # Read up to 100 MB of data at a time.
         blk_size = min(data_left, (100000000 // n_bytes // nchan) * nchan)
-        with open(self._filenames[fi], "rb", buffering=0) as fid:
+        with open(self.filenames[fi], "rb", buffering=0) as fid:
             # extract data
             pointer = start * nchan * n_bytes
             fid.seek(sqd["dirs"][KIT.DIR_INDEX_RAW_DATA]["offset"] + pointer)
@@ -279,8 +279,8 @@ def _set_stimchannels(inst, info, stim, stim_code):
             stim = np.asarray(stim, int)
             if stim.max() >= inst._raw_extras[0]["nchan"]:
                 raise ValueError(
-                    "Got stim=%s, but sqd file only has %i channels"
-                    % (stim, inst._raw_extras[0]["nchan"])
+                    f"Got stim={stim}, but sqd file only has "
+                    f"{inst._raw_extras[0]['nchan']} channels."
                 )
 
         # modify info
@@ -392,7 +392,7 @@ class EpochsKIT(BaseEpochs):
         standardize_names=None,
         verbose=None,
     ):
-        if isinstance(events, (str, PathLike, Path)):
+        if isinstance(events, str | PathLike | Path):
             events = read_events(events)
 
         input_fname = str(
@@ -404,7 +404,7 @@ class EpochsKIT(BaseEpochs):
         )
         kit_info.update(input_fname=input_fname)
         self._raw_extras = [kit_info]
-        self._filenames = []
+        self.filenames = []
         if len(events) != self._raw_extras[0]["n_epochs"]:
             raise ValueError("Event list does not match number of epochs.")
 
@@ -535,7 +535,7 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
         # check file format version
         version, revision = np.fromfile(fid, INT32, 2)
         if version < 2 or (version == 2 and revision < 3):
-            version_string = "V%iR%03i" % (version, revision)
+            version_string = f"V{version}R{revision:03d}"
             if allow_unknown_format:
                 unsupported_format = True
                 warn(f"Force loading KIT format {version_string}")
@@ -603,10 +603,9 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
             use_fll_type = fll_types[np.searchsorted(fll_types, fll_type) - 1]
             warn(
                 "Unknown site filter settings (FLL) for system "
-                '"%s" model "%s" (ID %s), will assume FLL %d->%d, check '
-                "your data for correctness, including channel scales and "
-                "filter settings!"
-                % (system_name, model_name, sysid, fll_type, use_fll_type)
+                f'"{system_name}" model "{model_name}" (ID {sysid}), will assume FLL '
+                f"{fll_type}->{use_fll_type}, check your data for correctness, "
+                "including channel scales and filter settings!"
             )
             fll_type = use_fll_type
 
@@ -628,8 +627,8 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
             if channel_type in KIT.CHANNELS_MEG:
                 if channel_type not in KIT.CH_TO_FIFF_COIL:
                     raise NotImplementedError(
-                        "KIT channel type %i can not be read. Please contact "
-                        "the mne-python developers." % channel_type
+                        "KIT channel type {channel_type} can not be read. Please "
+                        "contact the mne-python developers."
                     )
                 channels.append(
                     {
@@ -660,7 +659,7 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
             elif channel_type == KIT.CHANNEL_NULL:
                 channels.append({"type": channel_type})
             else:
-                raise OSError("Unknown KIT channel type: %i" % channel_type)
+                raise OSError("Unknown KIT channel type: {channel_type}")
         exg_gains = np.array(exg_gains)
 
         #
@@ -727,8 +726,8 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
                 sqd["n_samples"] = sqd["frame_length"] * sqd["n_epochs"]
         else:
             raise OSError(
-                "Invalid acquisition type: %i. Your file is neither "
-                "continuous nor epoched data." % (acq_type,)
+                f"Invalid acquisition type: {acq_type}. Your file is neither "
+                "continuous nor epoched data."
             )
 
         #
@@ -807,7 +806,7 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
     # precompute conversion factor for reading data
     if unsupported_format:
         if sysid not in LEGACY_AMP_PARAMS:
-            raise OSError("Legacy parameters for system ID %i unavailable" % (sysid,))
+            raise OSError(f"Legacy parameters for system ID {sysid} unavailable.")
         adc_range, adc_stored = LEGACY_AMP_PARAMS[sysid]
     is_meg = np.array([ch["type"] in KIT.CHANNELS_MEG for ch in channels])
     ad_to_volt = adc_range / (2.0**adc_stored)
@@ -843,7 +842,7 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
         if ch["type"] in KIT.CHANNELS_MEG:
             ch_name = ch.get("name", "")
             if ch_name == "" or standardize_names:
-                ch_name = "MEG %03d" % idx
+                ch_name = f"MEG {idx:03d}"
             # create three orthogonal vector
             # ch_angles[0]: theta, ch_angles[1]: phi
             theta, phi = np.radians(ch["loc"][3:])
@@ -878,7 +877,7 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
             eeg_name = ch_name.lower()
             # some files have all EEG labeled as EEG
             if ch_name in ("", "EEG") or standardize_names:
-                ch_name = "%s %03i" % (ch_type_label, ch_type_index)
+                ch_name = f"{ch_type_label} {ch_type_index:03d}"
             unit = FIFF.FIFF_UNIT_V
             loc = np.zeros(12)
             if eeg_name and eeg_name in dig:
