@@ -1,5 +1,4 @@
-# Authors: Robert Luke <mail@robertluke.net>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -35,7 +34,7 @@ from ._localized_abbr import _localized_abbr
 
 @fill_doc
 def read_raw_nirx(
-    fname, saturated="annotate", preload=False, verbose=None
+    fname, saturated="annotate", *, preload=False, encoding="latin-1", verbose=None
 ) -> "RawNIRX":
     """Reader for a NIRX fNIRS recording.
 
@@ -45,6 +44,7 @@ def read_raw_nirx(
         Path to the NIRX data folder or header file.
     %(saturated)s
     %(preload)s
+    %(encoding_nirx)s
     %(verbose)s
 
     Returns
@@ -61,7 +61,9 @@ def read_raw_nirx(
     -----
     %(nirx_notes)s
     """
-    return RawNIRX(fname, saturated, preload, verbose)
+    return RawNIRX(
+        fname, saturated, preload=preload, encoding=encoding, verbose=verbose
+    )
 
 
 def _open(fname):
@@ -78,6 +80,7 @@ class RawNIRX(BaseRaw):
         Path to the NIRX data folder or header file.
     %(saturated)s
     %(preload)s
+    %(encoding_nirx)s
     %(verbose)s
 
     See Also
@@ -90,8 +93,8 @@ class RawNIRX(BaseRaw):
     """
 
     @verbose
-    def __init__(self, fname, saturated, preload=False, verbose=None):
-        logger.info("Loading %s" % fname)
+    def __init__(self, fname, saturated, *, preload=False, encoding=None, verbose=None):
+        logger.info(f"Loading {fname}")
         _validate_type(fname, "path-like", "fname")
         _validate_type(saturated, str, "saturated")
         _check_option("saturated", saturated, ("annotate", "nan", "ignore"))
@@ -102,10 +105,7 @@ class RawNIRX(BaseRaw):
         fname = str(_check_fname(fname, "read", True, "fname", need_dir=True))
 
         json_config = glob.glob(f"{fname}/*{'config.json'}")
-        if len(json_config):
-            is_aurora = True
-        else:
-            is_aurora = False
+        is_aurora = len(json_config)
 
         if is_aurora:
             # NIRSport2 devices using Aurora software
@@ -178,7 +178,7 @@ class RawNIRX(BaseRaw):
         # Read header file
         # The header file isn't compliant with the configparser. So all the
         # text between comments must be removed before passing to parser
-        with _open(files["hdr"]) as f:
+        with open(files["hdr"], encoding=encoding) as f:
             hdr_str_all = f.read()
         hdr_str = re.sub("#.*?#", "", hdr_str_all, flags=re.DOTALL)
         if is_aurora:
@@ -210,8 +210,8 @@ class RawNIRX(BaseRaw):
             ):
                 warn(
                     "Only import of data from NIRScout devices have been "
-                    "thoroughly tested. You are using a %s device. "
-                    % hdr["GeneralInfo"]["Device"]
+                    f'thoroughly tested. You are using a {hdr["GeneralInfo"]["Device"]}'
+                    " device."
                 )
 
         # Parse required header fields
@@ -242,6 +242,7 @@ class RawNIRX(BaseRaw):
                 '"%a %d %b %Y""%H:%M:%S.%f"',
                 '"%a, %d %b %Y""%H:%M:%S.%f"',
                 "%Y-%m-%d %H:%M:%S.%f",
+                '"%Y年%m月%d日""%H:%M:%S.%f"',
             ]:
                 try:
                     meas_date = dt.datetime.strptime(loc_datetime_str, dt_code)
@@ -343,7 +344,7 @@ class RawNIRX(BaseRaw):
         else:
             subject_info["sex"] = FIFF.FIFFV_SUBJ_SEX_UNKNOWN
         if inf["age"] != "":
-            subject_info["birthday"] = (
+            subject_info["birthday"] = dt.date(
                 meas_date.year - int(inf["age"]),
                 meas_date.month,
                 meas_date.day,
