@@ -1,8 +1,8 @@
-# Authors: Robert Luke  <mail@robertluke.net>
-#          simplified BSD-3 license
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
+import datetime
 import shutil
 
 import numpy as np
@@ -55,7 +55,6 @@ nirx_nirsport2_103_2 = (
 snirf_nirsport2_20219 = (
     testing_path / "SNIRF" / "NIRx" / "NIRSport2" / "2021.9" / "2021-10-01_002.snirf"
 )
-nirx_nirsport2_20219 = testing_path / "NIRx" / "nirsport_v2" / "aurora_2021_9"
 
 # Kernel
 kernel_hb = testing_path / "SNIRF" / "Kernel" / "Flow50" / "Portal_2021_11" / "hb.snirf"
@@ -516,7 +515,10 @@ def test_birthday(tmp_path, monkeypatch):
         a.save()
 
     raw = read_raw_snirf(fname)
-    assert raw.info["subject_info"]["birthday"] == (1950, 1, 1)
+    assert raw.info["subject_info"]["birthday"] == datetime.date(1950, 1, 1)
+    # TODO: trigger some setting checkers that should maybe be in the reader (like
+    # those for subject_info)
+    raw.info.copy()
 
 
 @requires_testing_data
