@@ -40,6 +40,7 @@ from mne.utils import (
     catch_logging,
     check_version,
     object_diff,
+    sizeof_fmt,
 )
 
 raw_fname = op.join(
@@ -314,10 +315,10 @@ def _test_raw_reader(
     ids = [id(ch["loc"]) for ch in raw.info["chs"]]
     assert len(set(ids)) == len(ids)
 
-    full_data = raw._data
+    full_data = raw.get_data()
     assert raw.__class__.__name__ in repr(raw)  # to test repr
     assert raw.info.__class__.__name__ in repr(raw.info)
-    assert isinstance(raw.info["dig"], (type(None), list))
+    assert isinstance(raw.info["dig"], type(None) | list)
     data_max = np.nanmax(full_data)
     data_min = np.nanmin(full_data)
     # these limits could be relaxed if we actually find data with
@@ -342,16 +343,19 @@ def _test_raw_reader(
         assert_array_equal(raw.times, raw2.times)
 
     # Test saving and reading
-    out_fname = op.join(tempdir, "test_raw.fif")
+    out_fname = op.join(tempdir, "test_out_raw.fif")
     raw = concatenate_raws([raw])
-    raw.save(out_fname, tmax=raw.times[-1], overwrite=True, buffer_size_sec=1)
-
+    filenames = raw.save(
+        out_fname, tmax=raw.times[-1], overwrite=True, buffer_size_sec=1
+    )
+    for filename in filenames:
+        assert filename.is_file()
     # Test saving with not correct extension
     out_fname_h5 = op.join(tempdir, "test_raw.h5")
     with pytest.raises(OSError, match="raw must end with .fif or .fif.gz"):
         raw.save(out_fname_h5)
 
-    raw3 = read_raw_fif(out_fname)
+    raw3 = read_raw_fif(out_fname, allow_maxshield="yes")
     assert_named_constants(raw3.info)
     assert set(raw.info.keys()) == set(raw3.info.keys())
     assert_allclose(
@@ -369,18 +373,21 @@ def _test_raw_reader(
     # Make sure concatenation works
     first_samp = raw.first_samp
     last_samp = raw.last_samp
-    concat_raw = concatenate_raws([raw.copy(), raw])
+    concat_raw = concatenate_raws([raw.copy(), raw], verbose="debug")
     assert concat_raw.n_times == 2 * raw.n_times
     assert concat_raw.first_samp == first_samp
     assert concat_raw.last_samp - last_samp + first_samp == last_samp + 1
     idx = np.where(concat_raw.annotations.description == "BAD boundary")[0]
+    assert len(idx) == 1
+    assert len(concat_raw.times) == 2 * n_samp
 
     expected_bad_boundary_onset = raw._last_time
 
     assert_array_almost_equal(
         concat_raw.annotations.onset[idx],
-        expected_bad_boundary_onset,
+        [expected_bad_boundary_onset],
         decimal=boundary_decimal,
+        err_msg="BAD boundary onset mismatch",
     )
 
     if raw.info["meas_id"] is not None:
@@ -536,12 +543,12 @@ def _test_raw_crop(reader, t_prop, kwargs):
     raw_2, raw_3 = raw_1.copy(), raw_1.copy()
     t_tot = raw_1.times[-1] * 3 + 2.0 / raw_1.info["sfreq"]
     raw_concat = concatenate_raws([raw_1, raw_2, raw_3])
-    assert len(raw_concat._filenames) == 3
+    assert len(raw_concat.filenames) == 3
     assert_allclose(raw_concat.times[-1], t_tot)
     assert_allclose(raw_concat.first_time, first_time)
     # keep all instances, but crop to t_start at the beginning
     raw_concat.crop(t_start, None)
-    assert len(raw_concat._filenames) == 3
+    assert len(raw_concat.filenames) == 3
     assert_allclose(raw_concat.times[-1], t_tot - t_start, atol=atol)
     assert_allclose(
         raw_concat.first_time,
@@ -551,7 +558,7 @@ def _test_raw_crop(reader, t_prop, kwargs):
     )
     # drop the first instance
     raw_concat.crop(crop_t, None)
-    assert len(raw_concat._filenames) == 2
+    assert len(raw_concat.filenames) == 2
     assert_allclose(raw_concat.times[-1], t_tot - t_start - crop_t, atol=atol)
     assert_allclose(
         raw_concat.first_time,
@@ -561,7 +568,7 @@ def _test_raw_crop(reader, t_prop, kwargs):
     )
     # drop the second instance, leaving just one
     raw_concat.crop(crop_t, None)
-    assert len(raw_concat._filenames) == 1
+    assert len(raw_concat.filenames) == 1
     assert_allclose(raw_concat.times[-1], t_tot - t_start - 2 * crop_t, atol=atol)
     assert_allclose(
         raw_concat.first_time,
@@ -771,15 +778,44 @@ def test_5839():
     assert raw_A.annotations.orig_time == _stamp_to_dt((0, 0))
 
 
-def test_repr():
+def test_duration_property():
+    """Test BaseRAW.duration property."""
+    sfreq = 1000
+    info = create_info(ch_names=["EEG 001"], sfreq=sfreq)
+    raw = BaseRaw(info, last_samps=[sfreq * 60 - 1])
+    assert raw.duration == 60
+
+
+@pytest.mark.parametrize("sfreq", [1, 10, 100, 1000])
+@pytest.mark.parametrize(
+    "duration, expected",
+    [
+        (0.1, "00:00:01"),
+        (1, "00:00:01"),
+        (59, "00:00:59"),
+        (59.1, "00:01:00"),
+        (60, "00:01:00"),
+        (60.1, "00:01:01"),
+        (61, "00:01:01"),
+        (61.1, "00:01:02"),
+    ],
+)
+def test_get_duration_string(sfreq, duration, expected):
+    """Test BaseRAW_get_duration_string() method."""
+    info = create_info(ch_names=["EEG 001"], sfreq=sfreq)
+    raw = BaseRaw(info, last_samps=[sfreq * duration - 1])
+    assert raw._get_duration_string() == expected
+
+
+@pytest.mark.parametrize("sfreq", [1, 10, 100, 256, 1000])
+def test_repr(sfreq):
     """Test repr of Raw."""
-    sfreq = 256
     info = create_info(3, sfreq)
-    raw = RawArray(np.zeros((3, 10 * sfreq)), info)
+    sample_count = 10 * sfreq
+    raw = RawArray(np.zeros((3, sample_count)), info)
     r = repr(raw)
-    assert (
-        re.search("<RawArray | 3 x 2560 (10.0 s), ~.* kB, data loaded>", r) is not None
-    ), r
+    size_str = sizeof_fmt(raw._size)
+    assert r == f"<RawArray | 3 x {sample_count} (10.0 s), ~{size_str}, data loaded>"
     assert raw._repr_html_()
 
 
@@ -1027,3 +1063,20 @@ def test_last_samp():
     raw = read_raw_fif(raw_fname).crop(0, 0.1).load_data()
     last_data = raw._data[:, [-1]]
     assert_array_equal(raw[:, -1][0], last_data)
+
+
+def test_rescale():
+    """Test rescaling channels."""
+    raw = read_raw_fif(raw_fname, preload=True)  # multiple channel types
+
+    with pytest.raises(ValueError, match="If scalings is a scalar, all channels"):
+        raw.rescale(2)  # need to use dict
+
+    orig = raw.get_data(picks="eeg")
+    raw.rescale({"eeg": 2})  # need to use dict
+    assert_allclose(raw.get_data(picks="eeg"), orig * 2)
+
+    raw.pick("mag")  # only a single channel type "mag"
+    orig = raw.get_data()
+    raw.rescale(4)  # a scalar works
+    assert_allclose(raw.get_data(), orig * 4)
