@@ -121,7 +121,7 @@ def _prepare_source_params(
     #   Pick the correct channels from the data
     #
     sel = _pick_channels_inverse_operator(inst.ch_names, inv)
-    logger.info("Picked %d channels from the data" % len(sel))
+    logger.info("Picked %d channels from the data", len(sel))
     logger.info("Computing inverse...")
     #
     #   Simple matrix multiplication followed by combination of the
@@ -135,7 +135,7 @@ def _prepare_source_params(
     # vertno: [lh_verts, rh_verts]
 
     k_idxs = None
-    if not isinstance(label, (Label, BiHemiLabel)):
+    if not isinstance(label, Label | BiHemiLabel):
         whole_K, whole_noise_norm, whole_vertno, _ = _assemble_kernel(
             inv, None, method, pick_ori, use_cps=use_cps
         )
@@ -146,7 +146,7 @@ def _prepare_source_params(
         else:
             assert not label
             K, noise_norm, vertno = whole_K, whole_noise_norm, whole_vertno
-    elif isinstance(label, (Label, BiHemiLabel)):
+    elif isinstance(label, Label | BiHemiLabel):
         K, noise_norm, vertno, _ = _assemble_kernel(
             inv, label, method, pick_ori, use_cps=use_cps
         )
@@ -156,7 +156,7 @@ def _prepare_source_params(
         rank = np.sum(s > 1e-8 * s[0])
         K = s[:rank] * U[:, :rank]
         Vh = Vh[:rank]
-        logger.info("Reducing data rank %d -> %d" % (len(s), rank))
+        logger.info("Reducing data rank %d -> %d", len(s), rank)
     else:
         Vh = None
     is_free_ori = inverse_operator["source_ori"] == FIFF.FIFFV_MNE_FREE_ORI
@@ -500,7 +500,7 @@ def _source_induced_power(
             types=(Label, BiHemiLabel, list, tuple, None),
             type_name=("Label or BiHemiLabel", "list of labels", "None"),
         )
-        if isinstance(label, (list, tuple)):
+        if isinstance(label, list | tuple):
             for item in label:
                 _validate_type(
                     item,
@@ -560,7 +560,7 @@ def _source_induced_power(
     power = sum(o[0] for o in out)  # power shape: (n_verts, n_freqs, n_samps)
     power /= len(epochs_data)  # average power over epochs
 
-    if isinstance(label, (Label, BiHemiLabel)):
+    if isinstance(label, Label | BiHemiLabel):
         logger.info(
             f"Outputting power for {len(power)} vertices in label {label.name}."
         )
@@ -979,9 +979,9 @@ def _compute_source_psd_epochs(
         n_epochs = len(epochs)
     except RuntimeError:
         n_epochs = len(epochs.events)
-        extra = "on at most %d epochs" % (n_epochs,)
+        extra = f"on at most {n_epochs} epochs"
     else:
-        extra = "on %d epochs" % (n_epochs,)
+        extra = f"on {n_epochs} epochs"
     if isinstance(bandwidth, str):
         bandwidth = f"{bandwidth} windowing"
     else:
@@ -1075,7 +1075,7 @@ def _compute_source_psd_epochs(
         )
 
         if return_sensor:
-            comment = "Epoch %d PSD" % (k,)
+            comment = f"Epoch {k} PSD"
             out = (
                 out,
                 EvokedArray(sensor_psd, evoked_info.copy(), freqs[0], comment, nave),
