@@ -1,11 +1,11 @@
-# Authors: Scott Huberty <seh33@uw.edu>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
 import numpy as np
 
 from ..._fiff.constants import FIFF
+from ...annotations import _annotations_starts_stops
 from ...io import BaseRaw
 from ...utils import _check_preload, _validate_type, logger, warn
 
@@ -14,7 +14,7 @@ def interpolate_blinks(raw, buffer=0.05, match="BAD_blink", interpolate_gaze=Fal
     """Interpolate eyetracking signals during blinks.
 
     This function uses the timing of blink annotations to estimate missing
-    data. Operates in place.
+    data. Missing values are then interpolated linearly. Operates in place.
 
     Parameters
     ----------
@@ -29,7 +29,8 @@ def interpolate_blinks(raw, buffer=0.05, match="BAD_blink", interpolate_gaze=Fal
     match : str | list of str
         The description of annotations to interpolate over. If a list, the data within
         all annotations that match any of the strings in the list will be interpolated
-        over. Defaults to ``'BAD_blink'``.
+        over. If a ``match`` starts with ``'BAD_'``, that part will be removed from the
+        annotation description after interpolation. Defaults to ``'BAD_blink'``.
     interpolate_gaze : bool
         If False, only apply interpolation to ``'pupil channels'``. If True, interpolate
         over ``'eyegaze'`` channels as well. Defaults to False, because eye position can
@@ -87,12 +88,15 @@ def _interpolate_blinks(raw, buffer, blink_annots, interpolate_gaze):
                 continue
         # Create an empty boolean mask
         mask = np.zeros_like(raw.times, dtype=bool)
-        for annot in blink_annots:
+        starts, ends = _annotations_starts_stops(raw, "BAD_blink")
+        starts = np.divide(starts, raw.info["sfreq"])
+        ends = np.divide(ends, raw.info["sfreq"])
+        for annot, start, end in zip(blink_annots, starts, ends):
             if "ch_names" not in annot or not annot["ch_names"]:
                 msg = f"Blink annotation missing values for 'ch_names' key: {annot}"
                 raise ValueError(msg)
-            start = annot["onset"] - pre_buffer
-            end = annot["onset"] + annot["duration"] + post_buffer
+            start -= pre_buffer
+            end += post_buffer
             if ch_info["ch_name"] not in annot["ch_names"]:
                 continue  # skip if the channel is not in the blink annotation
             # Update the mask for times within the current blink period
