@@ -1,8 +1,11 @@
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
+
 from pathlib import Path
 
 import numpy as np
+import pytest
 
 from mne import pick_types
 from mne.io import read_raw_fif
@@ -36,6 +39,10 @@ def test_find_ecg():
         events, ch_ECG, average_pulse, ecg = find_ecg_events(
             raw, event_id=999, ch_name=ch_name, tstart=tstart, return_ecg=True
         )
+        if ch_name is None:
+            assert ch_ECG is None
+        else:
+            assert raw.ch_names[ch_ECG] == ch_name
         assert raw.n_times == ecg.shape[-1]
         assert 40 < average_pulse < 60
         n_events = len(events)
@@ -110,3 +117,7 @@ def test_find_ecg():
     assert ecg_events.size == 0
     assert average_pulse == 0
     assert np.allclose(ecg, np.zeros_like(ecg))
+
+    # Needs MEG
+    with pytest.raises(ValueError, match="Generating an artificial"):
+        find_ecg_events(read_raw_fif(raw_fname, preload=False).pick("eeg"))
