@@ -55,6 +55,18 @@ def test_fix_stim_artifact():
     data_from_epochs_fix = epochs.get_data(copy=False)[:, :, tmin_samp:tmax_samp]
     assert not np.all(data_from_epochs_fix != 0)
 
+    baseline = (-0.1, -0.05)
+    epochs = fix_stim_artifact(
+        epochs, tmin=tmin, tmax=tmax, baseline=baseline, mode="constant"
+    )
+    b_start = int(np.ceil(epochs.info["sfreq"] * baseline[0]))
+    b_end = int(np.ceil(epochs.info["sfreq"] * baseline[1]))
+    base_t1 = b_start - e_start
+    base_t2 = b_end - e_start
+    baseline_mean = epochs.get_data()[:, :, base_t1:base_t2].mean(axis=2)[0][0]
+    data = epochs.get_data()[:, :, tmin_samp:tmax_samp]
+    assert data[0][0][0] == baseline_mean
+
     # use window before stimulus in raw
     event_idx = np.where(events[:, 2] == 1)[0][0]
     tmin, tmax = -0.045, -0.015
@@ -81,8 +93,22 @@ def test_fix_stim_artifact():
         raw, events, event_id=1, tmin=tmin, tmax=tmax, mode="window"
     )
     data, times = raw[:, (tidx + tmin_samp) : (tidx + tmax_samp)]
+
     assert np.all(data) == 0.0
 
+    raw = fix_stim_artifact(
+        raw,
+        events,
+        event_id=1,
+        tmin=tmin,
+        tmax=tmax,
+        baseline=baseline,
+        mode="constant",
+    )
+    data, times = raw[:, (tidx + tmin_samp) : (tidx + tmax_samp)]
+    baseline_mean, _ = raw[:, (tidx + b_start) : (tidx + b_end)]
+    assert baseline_mean.mean(axis=1)[0] == data[0][0]
+
     # get epochs from raw with fixed data
     tmin, tmax, event_id = -0.2, 0.5, 1
     epochs = Epochs(
@@ -117,3 +143,12 @@ def test_fix_stim_artifact():
     evoked = fix_stim_artifact(evoked, tmin=tmin, tmax=tmax, mode="window")
     data = evoked.data[:, tmin_samp:tmax_samp]
     assert np.all(data) == 0.0
+
+    evoked = fix_stim_artifact(
+        evoked, tmin=tmin, tmax=tmax, baseline=baseline, mode="constant"
+    )
+    base_t1 = int(baseline[0] * evoked.info["sfreq"]) - evoked.first
+    base_t2 = int(baseline[1] * evoked.info["sfreq"]) - evoked.first
+    data = evoked.data[:, tmin_samp:tmax_samp]
+    baseline_mean = evoked.data[:, base_t1:base_t2].mean(axis=1)[0]
+    assert data[0][0] == baseline_mean
