@@ -1,8 +1,4 @@
-# Authors: Yousra Bekhti <yousra.bekhti@gmail.com>
-#          Mark Wronkiewicz <wronk@uw.edu>
-#          Kostiantyn Maksymenko <kostiantyn.maksymenko@gmail.com>
-#          Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -73,7 +69,7 @@ def _uniform_stc(stc1, stc2):
     if len(stc1.vertices) != len(stc2.vertices):
         raise ValueError(
             "Data in stcs must have the same number of vertices "
-            "components. Got %d != %d." % (len(stc1.vertices), len(stc2.vertices))
+            f"components. Got {len(stc1.vertices)} != {len(stc2.vertices)}."
         )
     idx_start1 = 0
     idx_start2 = 0
@@ -179,7 +175,7 @@ def _check_threshold(threshold):
     if isinstance(threshold, str):
         if not threshold.endswith("%"):
             raise ValueError(
-                "Threshold if a string must end with " '"%%". Got %s.' % threshold
+                f'Threshold if a string must end with "%". Got {threshold}.'
             )
         threshold = float(threshold[:-1]) / 100.0
     threshold = float(threshold)
@@ -440,9 +436,7 @@ def _prepare_ppe_sd(stc_true, stc_est, src, threshold="50%"):
             n_dipoles += len(v)
             r_true = src[i]["rr"][v]
     if n_dipoles != 1:
-        raise ValueError(
-            "True source must contain only one dipole, got %d." % n_dipoles
-        )
+        raise ValueError(f"True source must contain only one dipole, got {n_dipoles}.")
 
     _, stc_est = _thresholding(None, stc_est, threshold)
 
