@@ -92,7 +92,7 @@ def linear_regression(inst, design_matrix, names=None):
         parameters = [p[name] for p in lm_params]
         for ii, value in enumerate(parameters):
             out_ = out.copy()
-            if not isinstance(out_, (SourceEstimate, Evoked)):
+            if not isinstance(out_, SourceEstimate | Evoked):
                 raise RuntimeError("Invalid container.")
             out_._data[:] = value
             parameters[ii] = out_
@@ -297,9 +297,10 @@ def linear_regression_raw(
     coefs = solver(X, data.T)
     if coefs.shape[0] != data.shape[0]:
         raise ValueError(
-            "solver output has unexcepted shape. Supply a "
+            f"solver output has unexcepted shape {coefs.shape}. Supply a "
             "function that returns coefficients in the form "
-            "(n_targets, n_features), where targets == channels."
+            "(n_targets, n_features), where "
+            f"n_targets == n_channels == {data.shape[0]}."
         )
 
     # construct Evoked objects to be returned from output
@@ -349,11 +350,11 @@ def _prepare_rerp_preds(
 
     # time windows (per event type) are converted to sample points from times
     # int(round()) to be safe and match Epochs constructor behavior
-    if isinstance(tmin, (float, int)):
+    if isinstance(tmin, float | int):
         tmin_s = {cond: int(round(tmin * sfreq)) for cond in conds}
     else:
         tmin_s = {cond: int(round(tmin.get(cond, -0.1) * sfreq)) for cond in conds}
-    if isinstance(tmax, (float, int)):
+    if isinstance(tmax, float | int):
         tmax_s = {cond: int(round(tmax * sfreq) + 1) for cond in conds}
     else:
         tmax_s = {cond: int(round(tmax.get(cond, 1.0) * sfreq)) + 1 for cond in conds}
