@@ -1,5 +1,4 @@
-# Authors: Marijn van Vliet <w.m.vanvliet@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -70,7 +69,7 @@ def _compare_bem_surfaces(surfs_1, surfs_2):
                 s1[name],
                 rtol=1e-3,
                 atol=1e-6,
-                err_msg='Mismatch: "%s"' % name,
+                err_msg=f'Mismatch: "{name}"',
             )
 
 
@@ -94,7 +93,7 @@ def _compare_bem_solutions(sol_a, sol_b):
     assert sol_a["solver"] == sol_b["solver"]
     for key in names[:-1]:
         assert_allclose(
-            sol_a[key], sol_b[key], rtol=1e-3, atol=1e-5, err_msg="Mismatch: %s" % key
+            sol_a[key], sol_b[key], rtol=1e-3, atol=1e-5, err_msg=f"Mismatch: {key}"
         )
 
 
@@ -202,7 +201,7 @@ def test_make_bem_model(tmp_path, kwargs, fname):
     if len(kwargs.get("conductivity", (0, 0, 0))) == 1:
         assert "distance" not in log
     else:
-        assert re.search(r"urfaces is approximately *3\.4 mm", log) is not None
+        assert re.search(r"surfaces is approximately *3\.4 mm", log) is not None
     assert re.search(r"inner skull CM is *0\.65 *-9\.62 *43\.85 mm", log) is not None
     model_c = read_bem_surfaces(fname)
     _compare_bem_surfaces(model, model_c)
@@ -308,7 +307,7 @@ def test_bem_solution(tmp_path, cond, fname):
     pytest.importorskip(
         "openmeeg",
         "2.5",
-        reason="OpenMEEG required to fully test BEM " "solution computation",
+        reason="OpenMEEG required to fully test BEM solution computation",
     )
     with catch_logging() as log:
         solution = make_bem_solution(model, solver="openmeeg", verbose=True)
