@@ -1,5 +1,4 @@
-# Author: Eric Larson <larson.eric.d@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -19,7 +18,6 @@ from numpy.testing import (
     assert_array_less,
     assert_equal,
 )
-from scipy import sparse
 
 from mne import (
     grow_labels,
@@ -37,6 +35,7 @@ from mne import (
     write_labels_to_annot,
 )
 from mne.datasets import testing
+from mne.fixes import _eye_array
 from mne.label import (
     Label,
     _blend_colors,
@@ -57,7 +56,6 @@ subjects_dir = data_path / "subjects"
 src_fname = subjects_dir / "sample" / "bem" / "sample-oct-6-src.fif"
 stc_fname = data_path / "MEG" / "sample" / "sample_audvis_trunc-meg-lh.stc"
 real_label_fname = data_path / "MEG" / "sample" / "labels" / "Aud-lh.label"
-real_label_rh_fname = data_path / "MEG" / "sample" / "labels" / "Aud-rh.label"
 v1_label_fname = subjects_dir / "sample" / "label" / "lh.V1.label"
 
 fwd_fname = data_path / "MEG" / "sample" / "sample_audvis_trunc-meg-eeg-oct-6-fwd.fif"
@@ -66,13 +64,12 @@ label_dir = subjects_dir / "sample" / "label" / "aparc"
 
 test_path = Path(__file__).parents[1] / "io" / "tests" / "data"
 label_fname = test_path / "test-lh.label"
-label_rh_fname = test_path / "test-rh.label"
 
 # This code was used to generate the "fake" test labels:
 # for hemi in ['lh', 'rh']:
 #    label = Label(np.unique((np.random.rand(100) * 10242).astype(int)),
 #                  hemi=hemi, comment='Test ' + hemi, subject='fsaverage')
-#    label.save(op.join(test_path, 'test-%s.label' % hemi))
+#    label.save(op.join(test_path, f'test-{hemi}.label'))
 
 
 # XXX : this was added for backward compat and keep the old test_label_in_src
@@ -133,7 +130,7 @@ def _stc_to_label(stc, src, smooth, subjects_dir=None):
         e = mesh_edges(this_tris)
         e.data[e.data == 2] = 1
         n_vertices = e.shape[0]
-        e = e + sparse.eye(n_vertices, n_vertices)
+        e = e + _eye_array(n_vertices)
 
         clusters = [this_vertno[np.any(this_data, axis=1)]]
 
@@ -150,7 +147,7 @@ def _stc_to_label(stc, src, smooth, subjects_dir=None):
                 idx_use = c
                 for k in range(smooth):
                     e_use = e[:, idx_use]
-                    data1 = e_use * np.ones(len(idx_use))
+                    data1 = e_use @ np.ones(len(idx_use))
                     idx_use = np.where(data1)[0]
 
                 label = Label(
