@@ -1,5 +1,4 @@
-# Author: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -503,6 +502,7 @@ def test_fit_matched_points(quats, scaling, do_scale):
     fro = rng.randn(10, 3)
     translation = rng.randn(3)
     for qi, quat in enumerate(quats):
+        print(qi)
         to = scaling * np.dot(quat_to_rot(quat), fro.T).T + translation
         for corrupted in (False, True):
             # mess up a point
