@@ -1,6 +1,4 @@
-# Authors : Alexandre Gramfort, alexandre.gramfort@inria.fr (2011)
-#           Denis A. Engemann <denis.engemann@gmail.com>
-# License : BSD-3-Clause
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -80,24 +78,17 @@ def _check_nfft(n, n_fft, n_per_seg, n_overlap):
     """Ensure n_fft, n_per_seg and n_overlap make sense."""
     if n_per_seg is None and n_fft > n:
         raise ValueError(
-            (
-                "If n_per_seg is None n_fft is not allowed to be > "
-                "n_times. If you want zero-padding, you have to set "
-                "n_per_seg to relevant length. Got n_fft of %d while"
-                " signal length is %d."
-            )
-            % (n_fft, n)
+            "If n_per_seg is None n_fft is not allowed to be > "
+            "n_times. If you want zero-padding, you have to set "
+            f"n_per_seg to relevant length. Got n_fft of {n_fft} while"
+            f" signal length is {n}."
         )
     n_per_seg = n_fft if n_per_seg is None or n_per_seg > n_fft else n_per_seg
     n_per_seg = n if n_per_seg > n else n_per_seg
     if n_overlap >= n_per_seg:
         raise ValueError(
-            (
-                "n_overlap cannot be greater than n_per_seg (or "
-                "n_fft). Got n_overlap of %d while n_per_seg is "
-                "%d."
-            )
-            % (n_overlap, n_per_seg)
+            "n_overlap cannot be greater than n_per_seg (or n_fft). Got n_overlap "
+            f"of {n_overlap} while n_per_seg is {n_per_seg}."
         )
     return n_fft, n_per_seg, n_overlap
 
@@ -200,7 +191,7 @@ def psd_array_welch(
     # Prep the PSD
     n_fft, n_per_seg, n_overlap = _check_nfft(n_times, n_fft, n_per_seg, n_overlap)
     win_size = n_fft / float(sfreq)
-    logger.info("Effective window size : %0.3f (s)" % win_size)
+    logger.info(f"Effective window size : {win_size:0.3f} (s)")
     freqs = np.arange(n_fft // 2 + 1, dtype=float) * (sfreq / n_fft)
     freq_mask = (freqs >= fmin) & (freqs <= fmax)
     if not freq_mask.any():
