@@ -1,8 +1,6 @@
 """Bunch-related classes."""
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Eric Larson <larson.eric.d@gmail.com>
-#          Joan Massich <mailsik@gmail.com>
-#
+
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -63,7 +61,7 @@ class _Named:
         return out
 
     def __str__(self):  # noqa: D105
-        return f"{str(self.__class__.mro()[-2](self))} ({self._name})"
+        return f"{self.__class__.mro()[-2](self)} ({self._name})"
 
     __repr__ = __str__
 
