@@ -12,8 +12,9 @@ import os.path as op
 import re
 import sys
 import warnings
+from collections.abc import Callable
 from io import StringIO
-from typing import Any, Callable, TypeVar
+from typing import Any, TypeVar
 
 from decorator import FunctionMaker
 
@@ -290,7 +291,7 @@ def set_log_file(fname=None, output_format="%(message)s", overwrite=None):
 def _remove_close_handlers(logger):
     for h in list(logger.handlers):
         # only remove our handlers (get along nicely with nose)
-        if isinstance(h, (logging.FileHandler, logging.StreamHandler)):
+        if isinstance(h, logging.FileHandler | logging.StreamHandler):
             if isinstance(h, logging.FileHandler):
                 h.close()
             logger.removeHandler(h)
