@@ -8,7 +8,7 @@ import numbers
 import operator
 import os
 import re
-from builtins import input  # noqa: UP029
+from builtins import input  # noqa: A004, UP029
 from difflib import get_close_matches
 from importlib import import_module
 from inspect import signature
@@ -52,10 +52,10 @@ def check_fname(fname, filetype, endings, endings_err=()):
 
     Parameters
     ----------
-    fname : str
+    fname : path-like
         Name of the file.
     filetype : str
-        Type of file. e.g., ICA, Epochs etc.
+        Type of file. e.g., ICA, Epochs, etc.
     endings : tuple
         Acceptable endings for the filename.
     endings_err : tuple
@@ -167,7 +167,35 @@ def _import_h5py():
 
 def _import_h5io_funcs():
     h5io = _soft_import("h5io", "HDF5-based I/O")
-    return h5io.read_hdf5, h5io.write_hdf5
+
+    # Saving to HDF5 does not support pathlib.Path objects, which are more and more used
+    # in MNE-Python.
+    # Related issue in h5io: https://github.com/h5io/h5io/issues/113
+    def cast_path_to_str(data: dict) -> dict:
+        """Cast all paths value to string in data."""
+        keys2cast = []
+        for key, value in data.items():
+            if isinstance(value, dict):
+                cast_path_to_str(value)
+            if isinstance(value, Path):
+                data[key] = value.as_posix()
+            if isinstance(key, Path):
+                keys2cast.append(key)
+        for key in keys2cast:
+            data[key.as_posix()] = data.pop(key)
+        return data
+
+    def write_hdf5(fname, data, *args, **kwargs):
+        """Write h5 and cast all paths to string in data."""
+        if isinstance(data, dict):
+            data = cast_path_to_str(data)
+        elif isinstance(data, list):
+            for k, elt in enumerate(data):
+                if isinstance(elt, dict):
+                    data[k] = cast_path_to_str(elt)
+        h5io.write_hdf5(fname, data, *args, **kwargs)
+
+    return h5io.read_hdf5, write_hdf5
 
 
 def _import_pymatreader_funcs(purpose):
@@ -186,7 +214,7 @@ def check_random_state(seed):
     """
     if seed is None or seed is np.random:
         return np.random.mtrand._rand
-    if isinstance(seed, (int, np.integer)):
+    if isinstance(seed, int | np.integer):
         return np.random.mtrand.RandomState(seed)
     if isinstance(seed, np.random.mtrand.RandomState):
         return seed
@@ -227,7 +255,7 @@ def _check_fname(
     *,
     check_bids_split=False,
     verbose=None,
-):
+) -> Path:
     """Check for file existence, and return its absolute path."""
     _validate_type(fname, "path-like", name)
     # special case for MNE-BIDS, check split
@@ -309,7 +337,7 @@ def _check_preload(inst, msg):
     from ..time_frequency import BaseTFR
     from ..time_frequency.spectrum import BaseSpectrum
 
-    if isinstance(inst, (BaseTFR, Evoked, BaseSpectrum, _BaseSourceEstimate)):
+    if isinstance(inst, BaseTFR | Evoked | BaseSpectrum | _BaseSourceEstimate):
         pass
     else:
         name = "epochs" if isinstance(inst, BaseEpochs) else "raw"
@@ -357,7 +385,7 @@ def _check_compensation_grade(info1, info2, name1, name2="data", ch_names=None):
         )
 
 
-def _soft_import(name, purpose, strict=True):
+def _soft_import(name, purpose, strict=True, *, min_version=None):
     """Import soft dependencies, providing informative errors on failure.
 
     Parameters
@@ -370,11 +398,6 @@ def _soft_import(name, purpose, strict=True):
     strict : bool
         Whether to raise an error if module import fails.
     """
-
-    # so that error msg lines are aligned
-    def indent(x):
-        return x.rjust(len(x) + 14)
-
     # Mapping import namespaces to their pypi package name
     pip_name = dict(
         sklearn="scikit-learn",
@@ -387,27 +410,31 @@ def _soft_import(name, purpose, strict=True):
         pyvista="pyvistaqt",
     ).get(name, name)
 
+    got_version = None
     try:
         mod = import_module(name)
-        return mod
     except (ImportError, ModuleNotFoundError):
-        if strict:
-            raise RuntimeError(
-                f"For {purpose} to work, the {name} module is needed, "
-                + "but it could not be imported.\n"
-                + "\n".join(
-                    (
-                        indent(
-                            "use the following installation method "
-                            "appropriate for your environment:"
-                        ),
-                        indent(f"'pip install {pip_name}'"),
-                        indent(f"'conda install -c conda-forge {pip_name}'"),
-                    )
-                )
-            )
-        else:
-            return False
+        mod = False
+    else:
+        have, got_version = check_version(
+            name,
+            min_version=min_version,
+            return_version=True,
+        )
+        if not have:
+            mod = False
+    if mod is False and strict:
+        extra = "" if min_version is None else f">={min_version}"
+        if got_version is not None:
+            extra += f" (found version {got_version})"
+        raise RuntimeError(
+            f"For {purpose} to work, the module {name}{extra} is needed, "
+            "but it could not be imported. Use the following installation method "
+            "appropriate for your environment:\n\n"
+            f"    pip install {pip_name}\n"
+            f"    conda install -c conda-forge {pip_name}"
+        )
+    return mod
 
 
 def _check_pandas_installed(strict=True):
@@ -578,7 +605,7 @@ def _validate_type(item, types=None, item_name=None, type_name=None, *, extra=""
     elif types == "info":
         from .._fiff.meas_info import Info as types
 
-    if not isinstance(types, (list, tuple)):
+    if not isinstance(types, list | tuple):
         types = [types]
 
     check_types = sum(
