@@ -30,6 +30,10 @@ from .misc import _pl
 _temp_home_dir = None
 
 
+class UnknownPlatformError(Exception):
+    """Exception raised for unknown platforms."""
+
+
 def set_cache_dir(cache_dir):
     """Set the directory to be used for temporary file storage.
 
@@ -212,6 +216,7 @@ _known_config_wildcards = (
     "MNE_NIRS",  # mne-nirs
     "MNE_KIT2FIFF",  # mne-kit-gui
     "MNE_ICALABEL",  # mne-icalabel
+    "MNE_LSL",  # mne-lsl
 )
 
 
@@ -605,12 +610,53 @@ def _get_gpu_info():
     return out
 
 
+def _get_total_memory():
+    """Return the total memory of the system in bytes."""
+    if platform.system() == "Windows":
+        o = subprocess.check_output(
+            [
+                "powershell.exe",
+                "(Get-CimInstance Win32_ComputerSystem).TotalPhysicalMemory",
+            ]
+        ).decode()
+        total_memory = int(o)
+    elif platform.system() == "Linux":
+        o = subprocess.check_output(["free", "-b"]).decode()
+        total_memory = int(o.splitlines()[1].split()[1])
+    elif platform.system() == "Darwin":
+        o = subprocess.check_output(["sysctl", "hw.memsize"]).decode()
+        total_memory = int(o.split(":")[1].strip())
+    else:
+        raise UnknownPlatformError("Could not determine total memory")
+
+    return total_memory
+
+
+def _get_cpu_brand():
+    """Return the CPU brand string."""
+    if platform.system() == "Windows":
+        o = subprocess.check_output(
+            ["powershell.exe", "(Get-CimInstance Win32_Processor).Name"]
+        ).decode()
+        cpu_brand = o.strip().splitlines()[-1]
+    elif platform.system() == "Linux":
+        o = subprocess.check_output(["grep", "model name", "/proc/cpuinfo"]).decode()
+        cpu_brand = o.splitlines()[0].split(": ")[1]
+    elif platform.system() == "Darwin":
+        o = subprocess.check_output(["sysctl", "machdep.cpu"]).decode()
+        cpu_brand = o.split("brand_string: ")[1].strip()
+    else:
+        cpu_brand = "?"
+
+    return cpu_brand
+
+
 def sys_info(
     fid=None,
     show_paths=False,
     *,
     dependencies="user",
-    unicode=True,
+    unicode="auto",
     check_version=True,
 ):
     """Print system information.
@@ -627,8 +673,9 @@ def sys_info(
     dependencies : 'user' | 'developer'
         Show dependencies relevant for users (default) or for developers
         (i.e., output includes additional dependencies).
-    unicode : bool
-        Include Unicode symbols in output.
+    unicode : bool | "auto"
+        Include Unicode symbols in output. If "auto", corresponds to True on Linux and
+        macOS, and False on Windows.
 
         .. versionadded:: 0.24
     check_version : bool | float
@@ -641,6 +688,13 @@ def sys_info(
     _validate_type(dependencies, str)
     _check_option("dependencies", dependencies, ("user", "developer"))
     _validate_type(check_version, (bool, "numeric"), "check_version")
+    _validate_type(unicode, (bool, str), "unicode")
+    _check_option("unicode", unicode, ("auto", True, False))
+    if unicode == "auto":
+        if platform.system() in ("Darwin", "Linux"):
+            unicode = True
+        else:  # Windows
+            unicode = False
     ljust = 24 if dependencies == "developer" else 21
     platform_str = platform.platform()
 
@@ -648,15 +702,20 @@ def sys_info(
     out("Platform".ljust(ljust) + platform_str + "\n")
     out("Python".ljust(ljust) + str(sys.version).replace("\n", " ") + "\n")
     out("Executable".ljust(ljust) + sys.executable + "\n")
-    out("CPU".ljust(ljust) + f"{platform.processor()} ")
+    try:
+        cpu_brand = _get_cpu_brand()
+    except Exception:
+        cpu_brand = "?"
+    out("CPU".ljust(ljust) + f"{cpu_brand} ")
     out(f"({multiprocessing.cpu_count()} cores)\n")
     out("Memory".ljust(ljust))
     try:
-        import psutil
-    except ImportError:
-        out('Unavailable (requires "psutil" package)')
+        total_memory = _get_total_memory()
+    except UnknownPlatformError:
+        total_memory = "?"
     else:
-        out(f"{psutil.virtual_memory().total / float(2 ** 30):0.1f} GB\n")
+        total_memory = f"{total_memory / 1024**3:.1f}"  # convert to GiB
+    out(f"{total_memory} GiB\n")
     out("\n")
     ljust -= 3  # account for +/- symbols
     libs = _get_numpy_libs()
@@ -713,10 +772,12 @@ def sys_info(
         use_mod_names += (
             "# Testing",
             "pytest",
-            "nbclient",
             "statsmodels",
             "numpydoc",
             "flake8",
+            "jupyter_client",
+            "nbclient",
+            "nbformat",
             "pydocstyle",
             "nitime",
             "imageio",
