@@ -17,8 +17,8 @@ Significant performance gains can be achieved by ensuring that inputs
 are Fortran contiguous because that's what LAPACK requires. Without this,
 inputs will be memcopied.
 """
-# Authors: Eric Larson <larson.eric.d@gmail.com>
-#
+
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -28,6 +28,8 @@ import numpy as np
 from scipy import linalg
 from scipy._lib._util import _asarray_validated
 
+from ..fixes import _safe_svd
+
 # For efficiency, names should be str or tuple of str, dtype a builtin
 # NumPy dtype
 
@@ -83,7 +85,7 @@ def _repeated_svd(x, lwork, overwrite_a=False):
     if info > 0:
         raise np.linalg.LinAlgError("SVD did not converge")
     if info < 0:
-        raise ValueError("illegal value in %d-th argument of internal gesdd" % -info)
+        raise ValueError(f"illegal value in {-info}-th argument of internal gesdd")
     return u, s, v
 
 
@@ -132,15 +134,13 @@ def eigh(a, overwrite_a=False, check_finite=True):
     if info == 0:
         return w, v
     if info < 0:
-        raise ValueError(
-            "illegal value in argument %d of internal %s" % (-info, driver)
-        )
+        raise ValueError(f"illegal value in argument {-info} of internal {driver}")
     else:
         raise linalg.LinAlgError(
             "internal fortran routine failed to converge: "
-            "%i off-diagonal elements of an "
+            f"{info} off-diagonal elements of an "
             "intermediate tridiagonal form did not converge"
-            " to zero." % info
+            " to zero."
         )
 
 
@@ -188,3 +188,56 @@ def _sym_mat_pow(A, power, rcond=1e-7, reduce_rank=False, return_s=False):
     if return_s:
         out = (out, s)
     return out
+
+
+# SciPy deprecation of pinv + pinvh rcond (never worked properly anyway)
+def pinvh(a, rtol=None):
+    """Compute a pseudo-inverse of a Hermitian matrix.
+
+    Parameters
+    ----------
+    a : ndarray, shape (n, n)
+        The Hermitian array to invert.
+    rtol : float | None
+        The relative tolerance.
+
+    Returns
+    -------
+    a_pinv : ndarray, shape (n, n)
+        The pseudo-inverse of a.
+    """
+    s, u = np.linalg.eigh(a)
+    del a
+    if rtol is None:
+        rtol = s.size * np.finfo(s.dtype).eps
+    maxS = np.max(np.abs(s))
+    above_cutoff = abs(s) > maxS * rtol
+    psigma_diag = 1.0 / s[above_cutoff]
+    u = u[:, above_cutoff]
+    return (u * psigma_diag) @ u.conj().T
+
+
+def pinv(a, rtol=None):
+    """Compute a pseudo-inverse of a matrix.
+
+    Parameters
+    ----------
+    a : ndarray, shape (n, m)
+        The array to invert.
+    rtol : float | None
+        The relative tolerance.
+
+    Returns
+    -------
+    a_pinv : ndarray, shape (m, n)
+        The pseudo-inverse of a.
+    """
+    u, s, vh = _safe_svd(a, full_matrices=False)
+    del a
+    maxS = np.max(s)
+    if rtol is None:
+        rtol = max(vh.shape + u.shape) * np.finfo(u.dtype).eps
+    rank = np.sum(s > maxS * rtol)
+    u = u[:, :rank]
+    u /= s[:rank]
+    return (u @ vh[:rank]).conj().T
