@@ -43,7 +43,7 @@ def _empty_hash(kind="md5"):
 
 def _pl(x, non_pl="", pl="s"):
     """Determine if plural should be used."""
-    len_x = x if isinstance(x, (int, np.generic)) else len(x)
+    len_x = x if isinstance(x, int | np.generic) else len(x)
     return non_pl if len_x == 1 else pl
 
 
@@ -333,7 +333,7 @@ def sizeof_fmt(num):
     size : str
         The size in human-readable format.
     """
-    units = ["bytes", "kB", "MB", "GB", "TB", "PB"]
+    units = ["bytes", "KiB", "MiB", "GiB", "TiB", "PiB"]
     decimals = [0, 0, 1, 2, 2, 2]
     if num > 1:
         exponent = min(int(log(num, 1024)), len(units) - 1)
@@ -389,7 +389,7 @@ def _assert_no_instances(cls, when=""):
                     and r is not locals()
                     and not inspect.isframe(r)
                 ):
-                    if isinstance(r, (list, dict, tuple)):
+                    if isinstance(r, list | dict | tuple):
                         rep = f"len={len(r)}"
                         r_ = gc.get_referrers(r)
                         types = (_fullname(x) for x in r_)
