@@ -1,18 +1,20 @@
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
+
 from copy import deepcopy
-from datetime import datetime, timezone
+from datetime import date
 from io import StringIO
 from pathlib import Path
 
 import numpy as np
 import pytest
 from numpy.testing import assert_allclose, assert_array_equal
-from scipy import sparse
 
 from mne import pick_types, read_cov, read_evokeds
 from mne._fiff.pick import _picks_by_type
 from mne.epochs import make_fixed_length_epochs
+from mne.fixes import _eye_array
 from mne.io import read_raw_fif
 from mne.time_frequency import tfr_morlet
 from mne.utils import (
@@ -20,14 +22,13 @@ from mne.utils import (
     _apply_scaling_array,
     _apply_scaling_cov,
     _array_equal_nan,
-    _cal_to_julian,
     _custom_lru_cache,
-    _dt_to_julian,
+    _date_to_julian,
     _freq_mask,
     _get_inst_data,
-    _julian_to_cal,
-    _julian_to_dt,
+    _julian_to_date,
     _reg_pinv,
+    _replace_md5,
     _ReuseCycle,
     _time_mask,
     _undo_scaling_array,
@@ -314,8 +315,8 @@ def test_object_size():
         (150, 500, np.ones(20)),
         (30, 400, dict()),
         (400, 1000, dict(a=np.ones(50))),
-        (200, 900, sparse.eye(20, format="csc")),
-        (200, 900, sparse.eye(20, format="csr")),
+        (200, 900, _eye_array(20, format="csc")),
+        (200, 900, _eye_array(20, format="csr")),
     ):
         size = object_size(obj)
         assert lower < size < upper, f"{lower} < {size} < {upper}:\n{obj}"
@@ -416,14 +417,14 @@ def test_hash():
     pytest.raises(RuntimeError, object_diff, d1, d2)
     pytest.raises(RuntimeError, object_hash, d1)
 
-    x = sparse.eye(2, 2, format="csc")
-    y = sparse.eye(2, 2, format="csr")
+    x = _eye_array(2, format="csc")
+    y = _eye_array(2, format="csr")
     assert "type mismatch" in object_diff(x, y)
-    y = sparse.eye(2, 2, format="csc")
+    y = _eye_array(2, format="csc")
     assert len(object_diff(x, y)) == 0
     y[1, 1] = 2
     assert "elements" in object_diff(x, y)
-    y = sparse.eye(3, 3, format="csc")
+    y = _eye_array(3, format="csc")
     assert "shape" in object_diff(x, y)
     y = 0
     assert "type mismatch" in object_diff(x, y)
@@ -493,19 +494,12 @@ def test_julian_conversions():
     # A.D. 2018 Oct 3   12:00:00.0  2458395.000000
 
     jds = [2423219, 2458395, 2445701]
-    dds = [
-        datetime(1922, 6, 13, 12, 0, 0, tzinfo=timezone.utc),
-        datetime(2018, 10, 3, 12, 0, 0, tzinfo=timezone.utc),
-        datetime(1984, 1, 1, 12, 0, 0, tzinfo=timezone.utc),
-    ]
     cals = [(1922, 6, 13), (2018, 10, 3), (1984, 1, 1)]
+    dds = [date(*c) for c in cals]
 
     for dd, cal, jd in zip(dds, cals, jds):
-        assert dd == _julian_to_dt(jd)
-        assert cal == _julian_to_cal(jd)
-
-        assert jd == _dt_to_julian(dd)
-        assert jd == _cal_to_julian(cal[0], cal[1], cal[2])
+        assert dd == _julian_to_date(jd)
+        assert jd == _date_to_julian(dd)
 
 
 def test_grand_average_empty_sequence():
@@ -604,10 +598,27 @@ def test_custom_lru_cache():
     assert my_fun(1, np.array([2]), 3) == "int, ndarray, int"
     assert n_calls == [2, 1]
     assert len(_LRU_CACHES[fun_hash]) == 2
-    assert my_fun_2(1, sparse.eye(1, format="csc")) == "int, csc_matrix"
+    assert my_fun_2(1, _eye_array(1, format="csc")) == "int, csc_array"
     assert n_calls == [2, 2]
     assert len(_LRU_CACHES[fun_2_hash]) == 1  # other got popped
     # we could add support for this eventually, but don't bother for now
     with pytest.raises(RuntimeError, match="Unsupported sparse type"):
-        my_fun_2(1, sparse.eye(1, format="coo"))
+        my_fun_2(1, _eye_array(1, format="coo"))
     assert n_calls == [2, 2]  # never did any computation
+
+
+def test_replace_md5(tmp_path):
+    """Test _replace_md5."""
+    old = tmp_path / "test"
+    new = old.with_suffix(".new")
+    old.write_text("abcd")
+    new.write_text("abcde")
+    assert old.is_file()
+    assert new.is_file()
+    _replace_md5(str(new))
+    assert not new.is_file()
+    assert old.read_text() == "abcde"
+    new.write_text(old.read_text())
+    _replace_md5(str(new))
+    assert old.read_text() == "abcde"
+    assert not new.is_file()
