@@ -1,9 +1,4 @@
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Eric Larson <larson.eric.d@gmail.com>
-#          Oleh Kozynets <ok7mailbox@gmail.com>
-#          Guillaume Favelier <guillaume.favelier@gmail.com>
-#          jona-sassenhagen <jona.sassenhagen@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -95,7 +90,6 @@ class _Surface:
         self.coords = None
         self.curv = None
         self.faces = None
-        self.grey_curv = None
         self.nn = None
         self.labels = dict()
         self.x_dir = x_dir
@@ -174,18 +168,10 @@ class _Surface:
 
     def load_curvature(self):
         """Load in curvature values from the ?h.curv file."""
-        curv_path = path.join(self.data_path, "surf", "%s.curv" % self.hemi)
+        curv_path = path.join(self.data_path, "surf", f"{self.hemi}.curv")
         if path.isfile(curv_path):
             self.curv = read_curvature(curv_path, binary=False)
             self.bin_curv = np.array(self.curv > 0, np.int64)
-            color = (self.curv > 0).astype(float)
         else:
             self.curv = None
             self.bin_curv = None
-            color = np.ones(self.coords.shape[0])
-        # morphometry (curvature) normalization in order to get gray cortex
-        # TODO: delete self.grey_curv after cortex parameter
-        # will be fully supported
-        color = 0.5 - (color - 0.5) / 3
-        color = color[:, np.newaxis] * [1, 1, 1]
-        self.grey_curv = color
