@@ -93,7 +93,7 @@ class PyVistaFigure(Figure3D):
         self,
         plotter=None,
         show=False,
-        title="PyVista Scene",
+        title="MNE-Python 3D Figure",
         size=(600, 600),
         shape=(1, 1),
         background_color="black",
@@ -200,7 +200,8 @@ class _PyVistaRenderer(_AbstractRenderer):
         fig=None,
         size=(600, 600),
         bgcolor="black",
-        name="PyVista Scene",
+        *,
+        name=None,
         show=False,
         shape=(1, 1),
         notebook=None,
@@ -836,7 +837,7 @@ class _PyVistaRenderer(_AbstractRenderer):
         """Enable it everywhere except on systems with problematic OpenGL."""
         # MESA can't seem to handle MSAA and depth peeling simultaneously, see
         # https://github.com/pyvista/pyvista/issues/4867
-        bad_system = _is_mesa(self.plotter)
+        bad_system = _is_osmesa(self.plotter)
         for plotter in self._all_plotters:
             if bad_system or not self.antialias:
                 plotter.disable_anti_aliasing()
@@ -1187,10 +1188,17 @@ def _set_3d_view(
         _process_events(figure.plotter)
 
 
-def _set_3d_title(figure, title, size=16):
-    figure.plotter.add_text(title, font_size=size, color="white", name="title")
+def _set_3d_title(figure, title, size=16, *, color="white", position="upper_left"):
+    handle = figure.plotter.add_text(
+        title,
+        font_size=size,
+        color=color,
+        position=position,
+        name="title",
+    )
     figure.plotter.update()
     _process_events(figure.plotter)
+    return handle
 
 
 def _check_3d_figure(figure):
@@ -1311,10 +1319,11 @@ def _disabled_depth_peeling():
         depth_peeling["enabled"] = depth_peeling_enabled
 
 
-def _is_mesa(plotter):
+def _is_osmesa(plotter):
     # MESA (could use GPUInfo / _get_gpu_info here, but it takes
     # > 700 ms to make a new window + report capabilities!)
     # CircleCI's is: "Mesa 20.0.8 via llvmpipe (LLVM 10.0.0, 256 bits)"
+    # and a working Nouveau is: "Mesa 24.2.3-1ubuntu1 via NVE6"
     if platform.system() == "Darwin":  # segfaults on macOS sometimes
         return False
     gpu_info_full = plotter.ren_win.ReportCapabilities()
@@ -1323,8 +1332,9 @@ def _is_mesa(plotter):
         gpu_info_full,
     )
     gpu_info = " ".join(gpu_info).lower()
-    is_mesa = "mesa" in gpu_info.split()
-    if is_mesa:
+    is_osmesa = "mesa" in gpu_info.split()
+    print(is_osmesa)
+    if is_osmesa:
         # Try to warn if it's ancient
         version = re.findall("mesa ([0-9.]+)[ -].*", gpu_info) or re.findall(
             "OpenGL version string: .* Mesa ([0-9.]+)\n", gpu_info_full
@@ -1337,7 +1347,8 @@ def _is_mesa(plotter):
                     "surface rendering, consider upgrading to 18.3.6 or "
                     "later."
                 )
-    return is_mesa
+        is_osmesa = "via llvmpipe" in gpu_info
+    return is_osmesa
 
 
 class _SafeBackgroundPlotter(BackgroundPlotter):
