@@ -102,7 +102,6 @@ from ._pyvista import (
     _check_3d_figure,  # noqa: F401
     _close_3d_figure,  # noqa: F401
     _close_all,  # noqa: F401
-    _is_mesa,  # noqa: F401
     _PyVistaRenderer,
     _set_3d_title,  # noqa: F401
     _set_3d_view,  # noqa: F401
@@ -965,7 +964,7 @@ class _QtDialog(_AbstractDialog):
                         callback(button_name)
                     finally:
                         widget.unsetCursor()
-                        break
+                    break
 
         widget.buttonClicked.connect(func)
         return _QtDialogWidget(widget, modal)
@@ -1190,7 +1189,7 @@ class _QtDock(_AbstractDock, _QtLayout):
 
     def _dock_add_text(self, name, value, placeholder, *, callback=None, layout=None):
         layout = self._dock_layout if layout is None else layout
-        widget = QLineEdit(value)
+        widget = QLineEdit(str(value))
         widget.setPlaceholderText(placeholder)
         self._layout_add_widget(layout, widget)
         if callback is not None:
@@ -1213,6 +1212,8 @@ class _QtDock(_AbstractDock, _QtLayout):
     ):
         layout = self._dock_layout if layout is None else layout
         weakself = weakref.ref(self)
+        if initial_directory is not None:
+            initial_directory = str(initial_directory)
 
         def callback():
             self = weakself()
@@ -1654,7 +1655,7 @@ class _QtWidgetList(_AbstractWidgetList):
 
 class _QtWidget(_AbstractWdgt):
     def set_value(self, value):
-        if isinstance(self._widget, (QRadioButton, QToolButton, QPushButton)):
+        if isinstance(self._widget, QRadioButton | QToolButton | QPushButton):
             self._widget.click()
         else:
             if hasattr(self._widget, "setValue"):
