@@ -370,6 +370,9 @@ def test_plot_ica_sources(raw_orig, browser_backend, monkeypatch):
     leg = ax.get_legend()
     assert len(leg.get_texts()) == len(ica.exclude) == 1
 
+    # test passing psd_args argument
+    ica.plot_sources(epochs, psd_args=dict(fmax=50))
+
     # plot with bad channels excluded
     ica.exclude = [0]
     ica.plot_sources(evoked)
