@@ -1,5 +1,4 @@
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -101,7 +100,6 @@ def test_add_background_image():
         # Background without changing aspect
         if ii == 0:
             ax_im = add_background_image(f, im)
-            return
             assert ax_im.get_aspect() == "auto"
             for ax in axs:
                 assert ax.get_aspect() == 1
