@@ -1,10 +1,6 @@
 """Functions to plot M/EEG data on topo (one axes per channel)."""
 
-# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
-#          Denis Engemann <denis.engemann@gmail.com>
-#          Martin Luessi <mluessi@nmr.mgh.harvard.edu>
-#          Eric Larson <larson.eric.d@gmail.com>
-#
+# Authors: The MNE-Python contributors.
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -14,7 +10,7 @@ from functools import partial
 import numpy as np
 from scipy import ndimage
 
-from .._fiff.pick import channel_type, pick_types
+from .._fiff.pick import _picks_to_idx, channel_type, pick_types
 from ..defaults import _handle_default
 from ..utils import Bunch, _check_option, _clean_names, _is_numeric, _to_rgb, fill_doc
 from .utils import (
@@ -164,14 +160,12 @@ def _iter_topography(
         else:
             in_box = False
         return (
-            ("%s (click to magnify)" % ch_names[closest])
-            if in_box
-            else "No channel here"
+            f"{ch_names[closest]} (click to magnify)" if in_box else "No channel here"
         )
 
     def format_coord_multiaxis(x, y, ch_name=None):
         """Update status bar with channel name under cursor."""
-        return "%s (click to magnify)" % ch_name
+        return f"{ch_name} (click to magnify)"
 
     fig.set_facecolor(fig_facecolor)
     if layout is None:
@@ -332,8 +326,7 @@ def _plot_topo(
 
     for ax, ch_idx in my_topo_plot:
         if layout.kind == "Vectorview-all" and ylim is not None:
-            this_type = {"mag": 0, "grad": 1}[channel_type(info, ch_idx)]
-            ylim_ = [v[this_type] if _check_vlim(v) else v for v in ylim]
+            ylim_ = ylim.get(channel_type(info, ch_idx))
         else:
             ylim_ = ylim
 
@@ -390,8 +383,9 @@ def _plot_topo_onpick(event, show_func):
 
 def _compute_ax_scalings(bn, xlim, ylim):
     """Compute scale factors for a unified plot."""
-    if isinstance(ylim[0], (tuple, list, np.ndarray)):
-        ylim = (ylim[0][0], ylim[1][0])
+    if isinstance(ylim, dict):
+        # Take the first (ymin, ymax) entry.
+        ylim = next(iter(ylim.values()))
     pos = bn.pos
     bn.x_s = pos[2] / (xlim[1] - xlim[0])
     bn.x_t = pos[0] - bn.x_s * xlim[0]
@@ -399,11 +393,6 @@ def _compute_ax_scalings(bn, xlim, ylim):
     bn.y_t = pos[1] - bn.y_s * ylim[0]
 
 
-def _check_vlim(vlim):
-    """Check the vlim."""
-    return not np.isscalar(vlim) and vlim is not None
-
-
 def _imshow_tfr(
     ax,
     ch_idx,
@@ -412,6 +401,7 @@ def _imshow_tfr(
     vmin,
     vmax,
     onselect,
+    *,
     ylim=None,
     tfr=None,
     freq=None,
@@ -424,7 +414,6 @@ def _imshow_tfr(
     mask_style="both",
     mask_cmap="Greys",
     mask_alpha=0.1,
-    is_jointplot=False,
     cnorm=None,
 ):
     """Show time-frequency map as two-dimensional image."""
@@ -475,6 +464,7 @@ def _imshow_tfr_unified(
     vmin,
     vmax,
     onselect,
+    *,
     ylim=None,
     tfr=None,
     freq=None,
@@ -556,7 +546,7 @@ def _plot_timeseries(
         )
         timestr = f"{x:6.3f} {xunit}: "
         if not nearby:
-            return "%s Nothing here" % timestr
+            return f"{timestr} Nothing here"
         labels = [""] * len(nearby) if labels is None else labels
         nearby_data = [(data[n], labels[n], times[n]) for n in nearby]
         ylabel = ax.get_ylabel()
@@ -576,7 +566,7 @@ def _plot_timeseries(
             s += f"{data_[ch_idx, idx]:7.2f} {yunit}"
             if trunc_labels:
                 label = label if len(label) <= 10 else f"{label[:6]}..{label[-2:]}"
-            s += " [%s] " % label if label else " "
+            s += f" [{label}] " if label else " "
         return s
 
     ax.format_coord = lambda x, y: _format_coord(x, y, labels=labels, ax=ax)
@@ -971,10 +961,20 @@ def _plot_evoked_topo(
         picks = new_picks
         types_used = ["grad"]
         unit = _handle_default("units")["grad"] if noise_cov is None else "NA"
-        y_label = "RMS amplitude (%s)" % unit
+        y_label = f"RMS amplitude ({unit})"
 
     if layout is None:
         layout = find_layout(info, exclude=exclude)
+    else:
+        layout = layout.pick(
+            "all",
+            exclude=_picks_to_idx(
+                info,
+                exclude if exclude != "bads" else info["bads"],
+                exclude=(),
+                allow_empty=True,
+            ),
+        )
 
     if not merge_channels:
         # XXX. at the moment we are committed to 1- / 2-sensor-types layouts
@@ -999,13 +999,11 @@ def _plot_evoked_topo(
             > 0
         )
         if is_meg:
-            types_used = list(types_used)[::-1]  # -> restore kwarg order
             picks = [
                 pick_types(info, meg=kk, ref_meg=False, exclude=exclude)
                 for kk in types_used
             ]
         elif is_nirs:
-            types_used = list(types_used)[::-1]  # -> restore kwarg order
             picks = [
                 pick_types(info, fnirs=kk, ref_meg=False, exclude=exclude)
                 for kk in types_used
@@ -1032,27 +1030,21 @@ def _plot_evoked_topo(
                 unit = _handle_default("units")[channel_type(info, ch_idx)]
             else:
                 unit = "NA"
-            y_label.append("Amplitude (%s)" % unit)
+            y_label.append(f"Amplitude ({unit})")
 
     if ylim is None:
         # find minima and maxima over all evoked data for each channel pick
-        ymaxes = np.array([max((e.data[t]).max() for e in evoked) for t in picks])
-        ymins = np.array([min((e.data[t]).min() for e in evoked) for t in picks])
-
-        ylim_ = (ymins, ymaxes)
+        ylim_ = dict()
+        for ch_type, p in zip(types_used, picks):
+            ylim_[ch_type] = [
+                min([e.data[p].min() for e in evoked]),
+                max([e.data[p].max() for e in evoked]),
+            ]
     elif isinstance(ylim, dict):
         ylim_ = _handle_default("ylim", ylim)
-        ylim_ = [ylim_[kk] for kk in types_used]
-        # extra unpack to avoid bug #1700
-        if len(ylim_) == 1:
-            ylim_ = ylim_[0]
-        else:
-            ylim_ = [np.array(yl) for yl in ylim_]
-            # Transposing to avoid Zipping confusion
-            if is_meg or is_nirs:
-                ylim_ = list(map(list, zip(*ylim_)))
+        ylim_ = {kk: ylim_[kk] for kk in types_used}
     else:
-        raise TypeError("ylim must be None or a dict. Got %s." % type(ylim))
+        raise TypeError(f"ylim must be None or a dict. Got {type(ylim)}.")
 
     data = [e.data for e in evoked]
     comments = [e.comment for e in evoked]
