@@ -384,7 +384,7 @@ def _get_channel_plotting_order(order, ch_types, picks=None):
             for pick_idx, pick_type in enumerate(ch_types)
             if order_type == pick_type
         ]
-    elif not isinstance(order, (np.ndarray, list, tuple)):
+    elif not isinstance(order, np.ndarray | list | tuple):
         raise ValueError(f'order should be array-like; got "{order}" ({type(order)}).')
     if picks is not None:
         order = [ch for ch in order if ch in picks]
@@ -1283,7 +1283,7 @@ def _plot_sensors_2d(
 
     connect_picker = True
     if show_names:
-        if isinstance(show_names, (list, np.ndarray)):  # only given channels
+        if isinstance(show_names, list | np.ndarray):  # only given channels
             indices = [list(ch_names).index(name) for name in show_names]
         else:  # all channels
             indices = range(len(pos))
@@ -1352,7 +1352,7 @@ def _compute_scalings(scalings, inst, remove_dc=False, duration=10):
     from ..io import BaseRaw
 
     scalings = _handle_default("scalings_plot_raw", scalings)
-    if not isinstance(inst, (BaseRaw, BaseEpochs)):
+    if not isinstance(inst, BaseRaw | BaseEpochs):
         raise ValueError("Must supply either Raw or Epochs")
 
     for key, value in scalings.items():
@@ -2390,14 +2390,16 @@ def _convert_psds(
         np.sqrt(psds, out=psds)
         psds *= scaling
         ylabel = rf"$\mathrm{{{unit}/\sqrt{{Hz}}}}$"
+        coef = 20
     else:
         psds *= scaling * scaling
         if "/" in unit:
             unit = f"({unit})"
         ylabel = rf"$\mathrm{{{unit}²/Hz}}$"
+        coef = 10
     if dB:
         np.log10(np.maximum(psds, np.finfo(float).tiny), out=psds)
-        psds *= 10
+        psds *= coef
         ylabel = r"$\mathrm{dB}\ $" + ylabel
     ylabel = "Power (" + ylabel if estimate == "power" else "Amplitude (" + ylabel
     ylabel += ")"
