@@ -20,6 +20,11 @@ if [ ! -z "$CONDA_ENV" ]; then
 		INSTALL_KIND="test"
 		STD_ARGS="--progress-bar off"
 	fi
+elif [[ "${MNE_CI_KIND}" == "pip" ]]; then
+	# Only used for 3.13 at the moment, just get test deps plus a few extras
+	# that we know are available
+	INSTALL_ARGS="nibabel scikit-learn numpydoc PySide6 mne-qt-browser"
+	INSTALL_KIND="test"
 else
 	test "${MNE_CI_KIND}" == "pip-pre"
 	STD_ARGS="$STD_ARGS --pre"
