@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _plot_brainstorm_phantom_ctf:
 
@@ -19,13 +18,14 @@ References
 # Authors: Eric Larson <larson.eric.d@gmail.com>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 
 import warnings
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
 import mne
 from mne import fit_dipole
@@ -41,18 +41,18 @@ data_path = bst_phantom_ctf.data_path(verbose=True)
 # Switch to these to use the higher-SNR data:
 # raw_path = op.join(data_path, 'phantom_200uA_20150709_01.ds')
 # dip_freq = 7.
-raw_path = data_path / 'phantom_20uA_20150603_03.ds'
-dip_freq = 23.
-erm_path = data_path / 'emptyroom_20150709_01.ds'
+raw_path = data_path / "phantom_20uA_20150603_03.ds"
+dip_freq = 23.0
+erm_path = data_path / "emptyroom_20150709_01.ds"
 raw = read_raw_ctf(raw_path, preload=True)
 
 # %%
 # The sinusoidal signal is generated on channel HDAC006, so we can use
 # that to obtain precise timing.
 
-sinusoid, times = raw[raw.ch_names.index('HDAC006-4408')]
+sinusoid, times = raw[raw.ch_names.index("HDAC006-4408")]
 plt.figure()
-plt.plot(times[times < 1.], sinusoid.T[times < 1.])
+plt.plot(times[times < 1.0], sinusoid.T[times < 1.0])
 
 # %%
 # Let's create some events using this signal by thresholding the sinusoid.
@@ -71,7 +71,7 @@ raw.plot()
 # Maxwell filtering:
 
 raw.apply_gradient_compensation(0)  # must un-do software compensation first
-mf_kwargs = dict(origin=(0., 0., 0.), st_duration=10.)
+mf_kwargs = dict(origin=(0.0, 0.0, 0.0), st_duration=10.0)
 raw = mne.preprocessing.maxwell_filter(raw, **mf_kwargs)
 raw.plot()
 
@@ -83,22 +83,23 @@ raw.plot()
 
 tmin = -0.5 / dip_freq
 tmax = -tmin
-epochs = mne.Epochs(raw, events, event_id=1, tmin=tmin, tmax=tmax,
-                    baseline=(None, None))
+epochs = mne.Epochs(
+    raw, events, event_id=1, tmin=tmin, tmax=tmax, baseline=(None, None)
+)
 evoked = epochs.average()
-evoked.plot(time_unit='s')
-evoked.crop(0., 0.)
+evoked.plot(time_unit="s")
+evoked.crop(0.0, 0.0)
 
 # %%
 # .. _plt_brainstorm_phantom_ctf_eeg_sphere_geometry:
 #
 # Let's use a :ref:`sphere head geometry model <eeg_sphere_model>`
 # and let's see the coordinate alignment and the sphere location.
-sphere = mne.make_sphere_model(r0=(0., 0., 0.), head_radius=0.08)
+sphere = mne.make_sphere_model(r0=(0.0, 0.0, 0.0), head_radius=0.08)
 
-mne.viz.plot_alignment(raw.info, subject='sample',
-                       meg='helmet', bem=sphere, dig=True,
-                       surfaces=['brain'])
+mne.viz.plot_alignment(
+    raw.info, subject="sample", meg="helmet", bem=sphere, dig=True, surfaces=["brain"]
+)
 del raw, epochs
 
 # %%
@@ -106,23 +107,22 @@ del raw, epochs
 # recording.
 
 raw_erm = read_raw_ctf(erm_path).apply_gradient_compensation(0)
-raw_erm = mne.preprocessing.maxwell_filter(raw_erm, coord_frame='meg',
-                                           **mf_kwargs)
+raw_erm = mne.preprocessing.maxwell_filter(raw_erm, coord_frame="meg", **mf_kwargs)
 cov = mne.compute_raw_covariance(raw_erm)
 del raw_erm
 
 with warnings.catch_warnings(record=True):
     # ignore warning about data rank exceeding that of info (75 > 71)
-    warnings.simplefilter('ignore')
+    warnings.simplefilter("ignore")
     dip, residual = fit_dipole(evoked, cov, sphere, verbose=True)
 
 # %%
 # Compare the actual position with the estimated one.
 
-expected_pos = np.array([18., 0., 49.])
+expected_pos = np.array([18.0, 0.0, 49.0])
 diff = np.sqrt(np.sum((dip.pos[0] * 1000 - expected_pos) ** 2))
-print('Actual pos:     %s mm' % np.array_str(expected_pos, precision=1))
-print('Estimated pos:  %s mm' % np.array_str(dip.pos[0] * 1000, precision=1))
-print('Difference:     %0.1f mm' % diff)
-print('Amplitude:      %0.1f nAm' % (1e9 * dip.amplitude[0]))
-print('GOF:            %0.1f %%' % dip.gof[0])
+print(f"Actual pos:     {np.array_str(expected_pos, precision=1)} mm")
+print(f"Estimated pos:  {np.array_str(dip.pos[0] * 1000, precision=1)} mm")
+print(f"Difference:     {diff:0.1f} mm")
+print(f"Amplitude:      {1e9 * dip.amplitude[0]:0.1f} nAm")
+print(f"GOF:            {dip.gof[0]:0.1f} %")
